options compress=YES;
libname data ''; 
libname output ''; 
libname earn '';
libname sdr '';

* PREP FOR TABLES 7 ;
* INPUT: ANNUAL 831 FILES WITH NEW VARIABLES(FROM AEJ_PREP_831_1CREATEVARS),
		 MASTER BENEFICIARY RECORD EXTRACT (FROM AEJ_PREP_MBR_2MERGE),
		 SUPPLEMENTAL SECURITY RECORD (FROM AEJ_PREP_SSR_2MERGE),
		 SDR (PROVIDED BY SSA OFFICE OF RESEARCH, EVALUATION, AND STATISTICS, 
			located in folder ../offices/data/originals) ;
		

* START WITH BASELINE 1999 APPLICATIONS;
data data.cba_prep1;
 set

 	data.tab_f831_cy1999
	(keep=ssn fld fld_yy fld_mm fld_qtr fld_dd bic al rdt dds do zip stnum n_ed
	bic_: al_: toc_: allow_: ed_: sev_: n_daysproc
	where=(fld_yy=1999)
	)

 	data.tab_f831_cy2000
	(keep=ssn fld fld_yy fld_mm fld_qtr fld_dd bic al rdt dds do zip stnum n_ed
	bic_: al_: toc_: allow_: ed_: sev_: n_daysproc
	where=(fld_yy=1999)
	)

 	data.tab_f831_cy2001
	(keep=ssn fld fld_yy fld_mm fld_qtr fld_dd bic al rdt dds do zip stnum n_ed
	bic_: al_: toc_: allow_: ed_: sev_: n_daysproc
	where=(fld_yy=1999)
	)
;

* Create new adjudication level and filing date variables to merge with SDR;
	select(al);
		when ("A")  adjulvl_cd="1";  
		when ("B")  adjulvl_cd="2";
		when ("C")  adjulvl_cd="2";
		when ("D")  adjulvl_cd="3";
		when ("E")  adjulvl_cd="4";
		when ("F")  adjulvl_cd="5";
		when ("G")  adjulvl_cd="1";  
		when ("I")  adjulvl_cd="1";  
		otherwise   adjulvl_cd="";
	end;

	if (fld="99999999" or fld="") then do;
		filing_dt=.;
		fyr=.;
	end;
    else do;
	    fyr=input(substr(fld,1,4),4.);
		filing_dt=MDY(input(substr(fld,5,2),2.),input(substr(fld,7,2),2.),fyr);
	end;

	drop fyr;
	if n_ed^=. then den_ed=1;
	if sev_den^=. then den_sev=1;
run;

* Create processing time average, merge into main dataset, and classify by terciles ;
proc sort data=data.cba_prep1 out=data.cba_prep1;
	by zip;
run;

proc means noprint data=data.cba_prep1 nway;
	class zip;
	var n_daysproc;
	output out=data.cba_collapse_daysproc
	MEAN(n_daysproc)=;
run;

data data.cba_prep1;
	merge 
		data.cba_prep1
			(in=from_mainx)
		data.cba_collapse_daysproc
			(keep=zip n_daysproc)
		;
	by zip;
	if from_mainx=1;
run;

* Merge in ZIP and online application from SDR ;
proc sort data=data.cba_prep1 out=data.cba_prep1;
	by ssn filing_dt adjulvl_cd;
run;

proc sort data=sdr.all_sdr_matches out=sdr.all_sdr_matches;
	by ssn filing_dt adjulvl_cd;
run;

data data.cba_prep1;
	merge 
		data.cba_prep1
			(in=from_mainx rename=(fld_yy=year fld_qtr=quarter zip=zip_831))
		sdr.all_sdr_matches
			(
			keep=ssn filing_dt adjulvl_cd zip5 
			rename=(zip5=zip_sdr)
			)
		;
	by ssn filing_dt adjulvl_cd;
	if from_mainx=1;
run;

proc sort data=data.cba_prep1 out=data.cba_prep1;
	by ssn filing_dt adjulvl_cd;
run;

* Merge in SSR/MBR final decision variables ;
data data.cba_prep1;
	merge 
		data.cba_prep1
			(in=from_mainx)
		data.ssrcer_prep2
		;
	by ssn filing_dt adjulvl_cd;
	if from_mainx=1;
run;

proc sort data=data.cba_prep1 out=data.cba_prep1;
	by ssn filing_dt adjulvl_cd;
run;

data data.cba_prep1;
	merge 
		data.cba_prep1
			(in=from_mainx)
		data.mbr_prep2
		;
	by ssn filing_dt adjulvl_cd;
	if from_mainx=1;
run;

data data.cba_prep1;
	set data.cba_prep1;
	
	* Use SDR as primary ZIP and supplement with 831 for other years ;
	if zip_sdr^='' then zip=zip_sdr;
		else if zip_sdr='' & zip_831^='' then zip=zip_831;
		else zip='';

	* Final decision ;
	if allow_dds=1 then allow_fin=1;
		else if allow_dds^=1 & (toc_ssiadult=1 | toc_ssikid=1) & n_denfinssi^=1 then allow_fin=1;
		else if allow_dds^=1 & toc_diadult=1 & n_allowfindi=1 then allow_fin=1;
		else allow_fin=0;

	if sev_den=1 and allow_fin=0 then sev_low=1; else sev_low=0;
	if sev_den=1 and allow_fin=1 then sev_med=1; else sev_med=0;

	* Categories: program X education x severity groups ;
	if toc_diadult=1 & sev_low=1 and ed_hsdrop=1 	then pgmedsev=1;
	if toc_diadult=1 & sev_low=1 and ed_hsgrad=1 	then pgmedsev=2; 
	if toc_diadult=1 & sev_low=1 and ed_collgrad=1 	then pgmedsev=3; 
	if toc_diadult=1 & sev_med=1 and ed_hsdrop=1 	then pgmedsev=4; 
	if toc_diadult=1 & sev_med=1 and ed_hsgrad=1 	then pgmedsev=5; 
	if toc_diadult=1 & sev_med=1 and ed_collgrad=1 	then pgmedsev=6; 
	if toc_diadult=1 & sev_high=1 and ed_hsdrop=1 	then pgmedsev=7; 
	if toc_diadult=1 & sev_high=1 and ed_hsgrad=1 	then pgmedsev=8;
	if toc_diadult=1 & sev_high=1 and ed_collgrad=1 then pgmedsev=9; 
	if toc_diadult=1 & sev_vh=1 and ed_hsdrop=1 	then pgmedsev=10; 
	if toc_diadult=1 & sev_vh=1 and ed_hsgrad=1 	then pgmedsev=11; 
	if toc_diadult=1 & sev_vh=1 and ed_collgrad=1 	then pgmedsev=12; 

	if toc_ssiadult=1 & sev_low=1 and ed_hsdrop=1 	then pgmedsev=13;
	if toc_ssiadult=1 & sev_low=1 and ed_hsgrad=1 	then pgmedsev=14; 
	if toc_ssiadult=1 & sev_low=1 and ed_collgrad=1 then pgmedsev=15; 
	if toc_ssiadult=1 & sev_med=1 and ed_hsdrop=1 	then pgmedsev=16; 
	if toc_ssiadult=1 & sev_med=1 and ed_hsgrad=1 	then pgmedsev=17; 
	if toc_ssiadult=1 & sev_med=1 and ed_collgrad=1 then pgmedsev=18; 
	if toc_ssiadult=1 & sev_high=1 and ed_hsdrop=1 	then pgmedsev=19; 
	if toc_ssiadult=1 & sev_high=1 and ed_hsgrad=1 	then pgmedsev=20;
	if toc_ssiadult=1 & sev_high=1 and ed_collgrad=1 then pgmedsev=21; 
	if toc_ssiadult=1 & sev_vh=1 and ed_hsdrop=1 	then pgmedsev=22; 
	if toc_ssiadult=1 & sev_vh=1 and ed_hsgrad=1 	then pgmedsev=23; 
	if toc_ssiadult=1 & sev_vh=1 and ed_collgrad=1 	then pgmedsev=24; 

	if toc_ssikid=1 & sev_low=1						then pgmedsev=25;
	if toc_ssikid=1 & sev_med=1  					then pgmedsev=26; 
	if toc_ssikid=1 & sev_high=1  					then pgmedsev=27; 
	if toc_ssikid=1 & sev_vh=1 						then pgmedsev=28; 

run;

* Collapse data to get summary statistics;
data data.cba_summstat;
	set data.cba_prep1 (where=(zip_charlong^='000000000' & bic='A' & al='A')
								rename=(zip=zip_charlong));

	* Create numeric ZIP to merge with ZIP data ;
	zip_char=substr(zip_charlong,1,5);
	zip=input(zip_char,5.);
run;

proc means noprint data=data.cba_summstat;
	class zip;
	var n_ed sev_low sev_med sev_high sev_vh den_ed den_sev;
	output out=data.cba_summstat
	SUM(n_ed den_ed sev_low sev_med sev_high sev_vh toc_diadult toc_ssiadult toc_ssikid)=
	sum_ed den_ed sum_sevlow sum_sevmed sum_sevhigh sum_sevvh sum_diadult sum_ssiadult sum_ssikid
	;
run;

* Collapse data to get number of applications and allowances by ZIP by severity by education;
data data.cba_collapse;
	set data.cba_prep1 (where=(zip_charlong^='000000000' & bic='A' & al='A')
								rename=(zip=zip_charlong));

	zip_char=substr(zip_charlong,1,5);
	zip=input(zip_char,5.);
run;

proc means noprint data=data.cba_collapse nway;
	class zip pgmedsev;
	var year
	toc_diadult toc_ssiadult toc_ssikid
	sev_low sev_med sev_high sev_vh
	ed_hsdrop ed_hsgrad ed_collgrad
	;
	output out=data.cba_collapse
	n(year)=t7count
	MEAN(
	toc_diadult toc_ssiadult toc_ssikid
	sev_low sev_med sev_high sev_vh
	ed_hsdrop ed_hsgrad ed_collgrad
	)=
	toc_diadult toc_ssiadult toc_ssikid
	sev_low sev_med sev_high sev_vh
	ed_hsdrop ed_hsgrad ed_collgrad
	;
run;

data data.cba_collapse;
	set data.cba_collapse;

	* Assign each group decrease for closing ZIP;
	if toc_diadult=1 & sev_low=1 		then cls_disc_pct=	0.0283;
	if toc_diadult=1 & sev_med=1 		then cls_disc_pct=	-0.318; 
	if toc_diadult=1 & sev_high=1 		then cls_disc_pct=	-0.124; 
	if toc_diadult=1 & sev_vh=1 		then cls_disc_pct=	-0.0256; 

	if toc_ssiadult=1 & sev_low=1 		then cls_disc_pct=	-0.111;
	if toc_ssiadult=1 & sev_med=1 		then cls_disc_pct=	-0.319; 
	if toc_ssiadult=1 & sev_high=1 		then cls_disc_pct=	-0.229; 
	if toc_ssiadult=1 & sev_vh=1 		then cls_disc_pct=	-0.0260; 

	if toc_ssikid=1 & sev_low=1			then cls_disc_pct=	-0.112;
	if toc_ssikid=1 & sev_med=1  		then cls_disc_pct=	-0.0932; 
	if toc_ssikid=1 & sev_high=1  		then cls_disc_pct=	-0.155; 
	if toc_ssikid=1 & sev_vh=1 			then cls_disc_pct=	-0.00893; 
	
	* Assign each group decrease for neighboring ZIP;	
	if toc_diadult=1 & sev_low=1 	 		then nbr_disc_pct=	 0.0470;
	if toc_diadult=1 & sev_med=1 	 	 	then nbr_disc_pct=	-0.183; 
	if toc_diadult=1 & sev_high=1 	 	 	then nbr_disc_pct=	-0.0901; 
	if toc_diadult=1 & sev_vh=1 	 	 	then nbr_disc_pct=	-0.0201;  

	if toc_ssiadult=1 & sev_low=1 	 	 	then nbr_disc_pct=	-0.0307;
	if toc_ssiadult=1 & sev_med=1 	 	 	then nbr_disc_pct=	-0.168; 
	if toc_ssiadult=1 & sev_high=1 	 	 	then nbr_disc_pct=	-0.158; 
	if toc_ssiadult=1 & sev_vh=1 	 	 	then nbr_disc_pct=	 0.0267; 

	if toc_ssikid=1 & sev_low=1				then nbr_disc_pct=	-0.0611;
	if toc_ssikid=1 & sev_med=1  			then nbr_disc_pct=	-0.0685; 
	if toc_ssikid=1 & sev_high=1  		 	then nbr_disc_pct=	-0.117; 
	if toc_ssikid=1 & sev_vh=1 			 	then nbr_disc_pct=	-0.00464;

	* Replicating Table 6's baseline application count_clss;
	if toc_diadult=1 & sev_low=1		then t6count_cls= 	6.6*4;
	if toc_diadult=1 & sev_med=1 		then t6count_cls=	4.4*4; 
	if toc_diadult=1 & sev_high=1 		then t6count_cls=	2.8*4; 
	if toc_diadult=1 & sev_vh=1 		then t6count_cls=	3.7*4; 

	if toc_ssiadult=1 & sev_low=1 		then t6count_cls=	8.5*4;
	if toc_ssiadult=1 & sev_med=1 		then t6count_cls=	2.2*4; 
	if toc_ssiadult=1 & sev_high=1 		then t6count_cls=	2.9*4; 
	if toc_ssiadult=1 & sev_vh=1 		then t6count_cls=	2.2*4; 

	if toc_ssikid=1 & sev_low=1			then t6count_cls=	2.3*4;
	if toc_ssikid=1 & sev_med=1  		then t6count_cls=	0.3*4; 
	if toc_ssikid=1 & sev_high=1  		then t6count_cls=	2.8*4; 
	if toc_ssikid=1 & sev_vh=1 			then t6count_cls=	0.2*4; 

	* Add-on: Replicating Table 6's baseline application count_nbrs;
	if toc_diadult=1 & sev_low=1		then t6count_nbr= 	7.1*4;
	if toc_diadult=1 & sev_med=1 		then t6count_nbr=	4.6*4; 
	if toc_diadult=1 & sev_high=1 		then t6count_nbr=	2.9*4; 
	if toc_diadult=1 & sev_vh=1 		then t6count_nbr=	3.8*4; 

	if toc_ssiadult=1 & sev_low=1 		then t6count_nbr=	9.4*4;
	if toc_ssiadult=1 & sev_med=1 		then t6count_nbr=	2.3*4; 
	if toc_ssiadult=1 & sev_high=1 		then t6count_nbr=	3.1*4; 
	if toc_ssiadult=1 & sev_vh=1 		then t6count_nbr=	2.3*4; 

	if toc_ssikid=1 & sev_low=1			then t6count_nbr=	2.7*4;
	if toc_ssikid=1 & sev_med=1  		then t6count_nbr=	0.3*4; 
	if toc_ssikid=1 & sev_high=1  		then t6count_nbr=	2.9*4; 
	if toc_ssikid=1 & sev_vh=1 			then t6count_nbr=	0.2*4; 

	/* Calculate number discouraged/not discouraged */

	t6_cls_disc=t6count_cls*(-cls_disc_pct); * number discouraged (cls_disc_pct is negative, so this is positive) ;
	t6_cls_keep=t6count_cls-t6_cls_disc;	 * total - number discouraged ;

	t6_nbr_disc=t6count_nbr*(-nbr_disc_pct);
	t6_nbr_keep=t6count_nbr-t6_nbr_disc;

	t7_cls_disc=t7count*(-cls_disc_pct);
	t7_cls_keep=t7count-t7_cls_disc;

	t7_nbr_disc=t7count*(-nbr_disc_pct);
	t7_nbr_keep=t7count-t7_nbr_disc;

	* Costs of benefits and insurance for discouraged: value of benefits - app cost savings - admin savings ;
	%macro gamma(crra,val);
	if sev_low=0 & toc_diadult=1 then 
		do;
			g&crra._cost_disc_di = (1300*12*2*&val.); * foregone benefits, 1300 for DI, 700 for SSI;
			g&crra._cost_disc_ins = (1600*2*&val.*.2); * foregone insurance value * prob(no coverage), 0 for children ;
		end;	
	else if sev_low=0 & toc_ssiadult=1 then 
		do;
			g&crra._cost_disc_di = (700*12*2*&val.);
			g&crra._cost_disc_ins = (1600*2*&val.*.5);
		end;

	else if sev_low=0 & toc_ssikid=1 then 
		do;
			g&crra._cost_disc_di = (700*12*2*&val.);
			g&crra._cost_disc_ins = 0;
		end;
	else if sev_low=1 then 
		do;
			g&crra._cost_disc_di = 0;
			g&crra._cost_disc_ins = 0;
		end;
	g&crra._cost_disc_diins = g&crra._cost_disc_di + g&crra._cost_disc_ins ;
	%mend gamma;

	%gamma(1,.67);
	%gamma(2,1.78);
	%gamma(4,6.71);

	* Costs for those who keep applying: applicant time + earnings decay;
	if sev_low=0 then 
		do;
			cost_keepcls_congst = (15*20*.5);* lose time to congestion and travel;
			cost_keepcls_travel = (.2*20*.5); 
			cost_keepcls_decay = 0;
		end;
	if sev_low=0 then 
		do;
			cost_keepnbr_congst = (15*20*.5);
			cost_keepnbr_travel = 0; 
			cost_keepnbr_decay = 0;
		end;

	if sev_low=1 & toc_ssikid^=1 then 
		do;
			cost_keepcls_congst = (15*20*.5);
			cost_keepcls_travel = (.2*20*.5);
			cost_keepcls_decay = (3.43*28);  
		end;	

	if sev_low=1 & toc_ssikid^=1 then 
		do;
			cost_keepnbr_congst = (15*20*.5);
			cost_keepnbr_travel = 0; 
			cost_keepnbr_decay = (1.76*28); 
		end;	

	if sev_low=1 & toc_ssikid=1 then 
		do;
			cost_keepcls_congst = (15*20*.5);
			cost_keepcls_travel = (.2*20*.5);
			cost_keepcls_decay = 0;  
		end;	

	if sev_low=1 & toc_ssikid=1 then 
		do;
			cost_keepnbr_congst = (15*20*.5);
			cost_keepnbr_travel = 0; 
			cost_keepnbr_decay = 0; 
		end;	

	* Application cost savings to applicant ;
	ben_disc_app = (40*20); 

	* Admin processing savings to govt from discouraged ;
	ben_disc_admin = (1818*1.2);	

	* For Table 6, calculate all costs separately (note we are only considering Scenario 1: M, H, VH deserving) ;
	%macro cost(table,crra,val);
		&table.g&crra.cost_cls_diins = &table._cls_disc * g&crra._cost_disc_diins ;
		&table.g&crra.cost_nbr_diins = &table._nbr_disc * g&crra._cost_disc_diins ;

		&table.g&crra.cost_cls_timedecay = (&table._cls_keep * (cost_keepcls_congst + cost_keepcls_travel + cost_keepcls_decay));
		&table.g&crra.cost_nbr_timedecay = (&table._nbr_keep * (cost_keepnbr_congst + cost_keepnbr_travel + cost_keepnbr_decay));

		&table.g&crra.ben_cls_adminapp	= &table._cls_disc * ben_disc_admin;
		&table.g&crra.ben_nbr_adminapp	= &table._nbr_disc * ben_disc_admin;

		&table.g&crra.ben_cls_appsave	= &table._cls_disc * ben_disc_app;
		&table.g&crra.ben_nbr_appsave	= &table._nbr_disc * ben_disc_app;
		

	%mend cost;
	
	%cost(t6,1,.67);
	%cost(t6,2,1.78);
	%cost(t6,4,6.71);
	%cost(t7,1,.67);

run;

* SUM COSTS OVER ZIP;
data data.cba_collapse_formerge;
	set data.cba_collapse 
		(keep=zip 
		t6_cls_disc t6_cls_keep t6_nbr_disc t6_nbr_keep 
		t7_cls_disc t7_cls_keep t7_nbr_disc t7_nbr_keep 
		t6g1: t6g2: t6g4: t7g1:);
run;

proc means noprint data=data.cba_collapse_formerge nway;
	class zip;
	var 
		t6_cls_disc t6_cls_keep t6_nbr_disc t6_nbr_keep 
		t7_cls_disc t7_cls_keep t7_nbr_disc t7_nbr_keep 
		t6g1: t6g2: t6g4: t7g1:
		;
	output out=data.cba_collapse_formerge
	SUM(t6_cls_disc t6_cls_keep t6_nbr_disc t6_nbr_keep 
		t7_cls_disc t7_cls_keep t7_nbr_disc t7_nbr_keep 
		t6g1: t6g2: t6g4: t7g1:)=
		;
run;

* Merge summ stats into main file;
data data.cba_collapse_formerge;
	merge 
		data.cba_collapse_formerge
		data.cba_summstat
		;
	by zip;
run;

* CONVERT TO STATA;
%let DIR=;
%macro stataexport(dsname);
proc export data=data.&dsname
     file="&DIR\&dsname..dta"
     dbms=DTA REPLACE;
run;
%mend stataexport;

%stataexport(cba_collapse_formerge);


run; quit;
