capture log close
clear all
set maxvar 10000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Create Appendix Figure A.10
Input:
	merged_FNreg_qtr_`date' (from AEJ_PREP_831_5FIGURE)
*/

/* *********************** */
/* **** PAPER FIGURES **** */
/* *********************** */
use "`data'\statsby\merged_FNreg_qtr_`date'.dta", clear;

/* Figure A.10: recipient subgroup graphs */
local type_r "recipients";

foreach stub in all {;
	twoway 	
		connected b_`stub'_r_ctsevmed b_`stub'_r_ctsevhigh b_`stub'_r_ctsevvh eqtryear if eqtryear>=-12, 
			lcolor(`color_`stub''*.75 `color_`stub''*1.25 `color_`stub''*2) 
			mcolor(`color_`stub''*.75 `color_`stub''*1.25 `color_`stub''*2) 
			lpattern(longdash shortdash dash_dot)
			lwidth(medthick medthick medthick)
			msymbol(t O S) 	
		title("Number of `type_r' by severity (log)", size(medsmall))
		xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 8)) xlab(-12(4)8)
		ytitle("Reduced form estimate", size(medsmall)) ysc(r(-.4(.1).1)) ylab(-.4(.1).1, nogrid)
		yline(0, lcolor(gray))
		xline(-1, lpattern(dash) lcolor(gray))
		legend(order(1 2 3) col(4) row(1) 
			label(1 "Medium") label(2 "High") label(3 "Very high"))
		graphregion(color(white))
		bgcolor(white)
		name(sev_r)
		;
};

foreach gp in r {;

foreach stub in all {;
	twoway 	
		connected b_`stub'_`gp'_ctbsmental b_`stub'_`gp'_ctbsmusc b_`stub'_`gp'_ctbsphys eqtryear if eqtryear>=-12, 
			lcolor(orange blue green) 
			mcolor(orange blue green) 
			lpattern(solid longdash shortdash)
			lwidth(medthick medthick medthick)
			msymbol(X t O) 	
		title("Number of `type_`gp'' by disability type (log)", size(medsmall))
		xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 8)) xlab(-12(4)8)
		ytitle("Reduced form estimate", size(medsmall)) ysc(r(-.2(.1).1)) ylab(-.2(.1).1, nogrid)
		yline(0, lcolor(gray))
		xline(-1, lpattern(dash) lcolor(gray))
		legend(order(1 2 3) col(3) row(1) 
			label(1 "Mental") label(2 "Musculoskeletal") label(3 "Other physical"))
		graphregion(color(white))
		bgcolor(white)
		name(bs_`gp')
		;
};

foreach stub in all {;
	twoway 	
		connected b_`stub'_`gp'_ctedhsdrop b_`stub'_`gp'_ctedhsgrad b_`stub'_`gp'_ctedcollgrad eqtryear if eqtryear>=-12, 
			lcolor(`color_`stub''*.5 `color_`stub''*1 `color_`stub''*1.5) 
			mcolor(`color_`stub''*.5 `color_`stub''*1 `color_`stub''*1.5) 
			lpattern(solid longdash shortdash)
			lwidth(medthick medthick medthick)
			msymbol(X t O) 	
		title("Number of `type_`gp'' by education (log)", size(medsmall))
		xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 8)) xlab(-12(4)8)
		ytitle("Reduced form estimate", size(medsmall)) ysc(r(-.2(.1).1)) ylab(-.2(.1).1, nogrid)
		yline(0, lcolor(gray))
		xline(-1, lpattern(dash) lcolor(gray))
		legend(order(1 2 3) col(3) row(1) 
			label(1 "HS dropout") label(2 "HS grad") label(3 "College grad"))
		graphregion(color(white))
		bgcolor(white)
		name(ed_`gp')
		;
};

foreach stub in all {;
	twoway 	
		connected b_`stub'_`gp'_ctage18to34 b_`stub'_`gp'_ctage35to49 b_`stub'_`gp'_ctage50plus eqtryear if eqtryear>=-12, 
			lcolor(`color_`stub''*.5 `color_`stub''*1 `color_`stub''*1.5) 
			mcolor(`color_`stub''*.5 `color_`stub''*1 `color_`stub''*1.5) 
			lpattern(solid longdash shortdash)
			lwidth(medthick medthick medthick)
			msymbol(X t O) 	
		title("Number of `type_`gp'' by age (log)", size(medsmall))
		xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 8)) xlab(-12(4)8)
		ytitle("Reduced form estimate", size(medsmall)) ysc(r(-.2(.1).1)) ylab(-.2(.1).1, nogrid)
		yline(0, lcolor(gray))
		xline(-1, lpattern(dash) lcolor(gray))
		legend(order(1 2 3) col(3) row(1) 
			label(1 "Ages 18-34") label(2 "Ages 35-49") label(3 "Ages 50+"))
		graphregion(color(white))
		bgcolor(white)
		name(age_`gp')
		;
};

foreach stub in all {;
	twoway 	
		connected b_`stub'_`gp'_ctpearn0 b_`stub'_`gp'_ctpearn5 b_`stub'_`gp'_ctpearn15 b_`stub'_`gp'_ctpearn25 eqtryear if eqtryear>=-12, 
			lcolor(`color_`stub''*.4 `color_`stub''*.75 `color_`stub''*1.25 `color_`stub''*2) 
			mcolor(`color_`stub''*.4 `color_`stub''*.75 `color_`stub''*1.25 `color_`stub''*2) 
			lpattern(solid longdash shortdash dash_dot)
			lwidth(medthick medthick medthick medthick)
			msymbol(t d T S) 	
		title("Number of `type_`gp'' by pre-application earnings", size(medsmall))
		xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 8)) xlab(-12(4)8)
		ytitle("Reduced form estimate", size(medsmall)) ysc(r(-.2(.1).2)) ylab(-.2(.1).2, nogrid)
		yline(0, lcolor(gray))
		xline(-1, lpattern(dash) lcolor(gray))
		legend(order(1 2 3 4) col(4) row(1) 
			label(1 "$0-$5K") label(2 "$5K-$15K") label(3 "$15K-$25K") label(4 "$25K+"))
		graphregion(color(white))
		bgcolor(white)
		ylabel(,nogrid)
		name(earn_`gp')
		;
};

graph combine 
	sev_`gp' bs_`gp' ed_`gp' earn_`gp'
	,
	altshrink cols(2) rows(2) 
	graphregion(color(white))
	saving("`output'\\figure10.gph", replace);
};
