capture log close
clear all
set maxvar 10000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Create Appendix Figure A.12
Input:
	merged_FNreg_qtr_`date' (from AEJ_PREP_831_5FIGURE)
*/

/* *********************** */
/* **** PAPER FIGURES **** */
/* *********************** */
use "`data'\statsby\merged_FNreg_qtr_`date'.dta", clear;

/* Figure A.12: Macro variables */
local title_cty_pop "Population";
local title_cty_pinc "Personal income";
local title_cty_wageqtr "Quarterly wage";
local title_cty_wagewk "Average weekly wage";
local title_cty_employcew "Employment";
local title_cty_employlau "Employment";
local title_cty_unemploylau "Unemployment";
local title_cty_lforce "Labor force";
local title_cty_urate "Unemployment rate";

foreach cov in cty_pop cty_lforce cty_urate cty_pinc {;
	
	twoway 	
			rarea hi95_`cov' lo95_`cov' eqtryear if eqtryear>=-12, lcolor(white) lwidth(vvthin) color(orange) fin(30) ||
			connected b_`cov' eqtryear if eqtryear>=-12, lcolor(orange) mcolor(orange) msymbol(X) 			
			title("`title_`cov''", size(medsmall))
			xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 8)) xlab(-12(4)8)
			ytitle("Reduced form estimate", size(medsmall)) 
			yline(0, lcolor(gray))
			xline(-1, lpattern(dash) lcolor(gray))
			legend(off)
			graphregion(color(white))
			bgcolor(white)
			ylabel(,nogrid)
			name(`cov')
			;		
		pause;		
};

graph combine 
	cty_pop cty_lforce cty_urate cty_pinc
	,
	altshrink cols(2) rows(2) 
	graphregion(color(white))
	saving("`output'\\figure12.gph", replace);
