capture log close
clear all
set maxvar 10000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Create Appendix Figure A.14
Input:
	FNreg_qtr_post`post'_all_a_ctnumwt.dta (from AEJ_PREP_831_4QTR_ALTWINDOW)
*/

/* ****************************************** */
/* **** CREATE ONE DATA SET OF ESTIMATES **** */
/* ****************************************** */

foreach post in 4 6 8 10 12 {;

	use "`data'\statsby\FNreg_qtr_post`post'_all_a_ctnumwt.dta", clear;
	
	keep _b_trtX* _se_trtX*; 
	gen _b_trtXeqtryear_18=0;
	gen _se_trtXeqtryear_18=0;
	gen id=1;
	reshape long _b_trtXeqtryear_ _se_trtXeqtryear_, i(id) j(eqtryear);
	rename _b_trtXeqtryear_ b_`post'_`var';
	rename _se_trtXeqtryear_ se_`post'_`var';
	
	gen hi95_`post'_`var'=b+1.96*se;
	gen lo95_`post'_`var'=b-1.96*se;
	drop id;
	replace eqtryear=eqtryear-20;

	twoway 	
		rarea hi95_`post'_all_a_ctnum lo95_`post'_all_a_ctnum eqtryear if eqtryear>=-12, lcolor(white) lwidth(vvthin) color(orange) fin(30) ||
		connected b_`post'_all_a_ctnum eqtryear if eqtryear>=-12, lcolor(orange) lwidth(medthick) mcolor(orange) msymbol(T) 
		title("Number of applicants (log): `post'-quarter window", size(medsmall))
		xtitle("Quarter relative to closing", size(medsmall)) xsc(r(-12 `post')) xlab(-12(4)`post')
		ytitle("Reduced form estimate", size(medsmall)) ysc(r(-.3 .1)) ylab(-.3(.1).1)
		yline(0, lcolor(gray))
		xline(-1, lpattern(dash) lcolor(gray))
		legend(off)
		graphregion(color(white))
		bgcolor(white)
		ylabel(,nogrid)
		name(app`post')
		;
} ;

graph combine app4 app6 app8 app10 app12,
	altshrink cols(2) rows(3)
	graphregion(color(white))
	saving("`output'\\figure14.gph", replace);
