%%% Create Appendix Figure A.17

% Output Setup
clear
fName      = 'Times';
fSize 	   = 8;
pSize1     = [4.2,3.2];
pPosition1 = [0.1,0.1,4.0,3.0];

%% Initial Setup
N  = 200;
h  = linspace(0,1,N);
gh = 1/3+2.5*(h-1/2).^2;
ph = 1.3*(h-1).^2+0.1;
ph = min(1,ph);

%% Appendix Figure A.17 -- Left Panel
figure
axes('YGrid','off','XGrid','off',...
     'FontName',fName,'FontSize',fSize);
hold on
box on
plot(h,gh,'-','LineWidth',1.5,'Color','black')
plot(h,1/4*ones(N,1),'-.','LineWidth',1.5,'Color','blue')
ylim([0,1])
yl = ylabel('g(h), \eta');
xl = xlabel('h');
tl = title('Baseline');

set(tl,'FontName',fName,'FontSize',fSize);
set(xl,'FontName',fName,'FontSize',fSize);
set(yl,'FontName',fName,'FontSize',fSize);
set(gca,'FontName',fName,'FontSize',fSize);
set(gca,'YTickLabel',[])
text(h(10),gh(10),'g(h)','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')
text(h(10),1/4,'\eta','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')
text(h(180),ph(180),'p(h)','FontName',fName,'FontSize',fSize,'VerticalAlignment','top')
text(h(160),0.3,'Pr(R|A,\eta)','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')

yyaxis right
plot(h,ph,':','LineWidth',2,'Color','black')
plot(h,0.3*ones(N,1),'--','LineWidth',1.5,'Color','green')
ax = gca;
ax.YAxis(2).Color = 'black';
ylim([0,1])
yl = ylabel('p(h)');
set(yl,'FontName',fName,'FontSize',fSize);
set(gcf,'paperunits','inches')
set(gcf,'papersize',pSize1)
set(gcf,'PaperPosition',pPosition1)
print('-dpdf','-r600' ,'figA17_model_baseline.pdf')
close

%% Appendix Figure A.17 -- Right Panel
figure
axes('YGrid','off','XGrid','off',...
     'FontName',fName,'FontSize',fSize);
hold on
box on
plot(h,gh,'-','LineWidth',1.5,'Color','black')
plot(h,1/4*ones(N,1),'-.','LineWidth',1.5,'Color','blue')
plot(h,0.35*ones(N,1),'-.','LineWidth',1.5,'Color','red')
ylim([0,1])
yl = ylabel('g(h), \eta');
xl = xlabel('h');
tl = title('Targeting efficiency decreases');

set(tl,'FontName',fName,'FontSize',fSize);
set(xl,'FontName',fName,'FontSize',fSize);
set(yl,'FontName',fName,'FontSize',fSize);
set(gca,'FontName',fName,'FontSize',fSize);
set(gca,'YTickLabel',[])
text(h(10),gh(10),'g(h)','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')
text(h(10),1/4,'\eta','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')
text(h(10),0.35,'\eta^{\prime}','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')
text(h(180),ph(180),'p(h)','FontName',fName,'FontSize',fSize,'VerticalAlignment','top')
text(h(160),0.15,'Pr(R|A,\eta^{\prime})','FontName',fName,'FontSize',fSize,'VerticalAlignment','bottom')

yyaxis right
plot(h,ph,':','LineWidth',2,'Color','black')
plot(h,0.2*ones(N,1),'--','LineWidth',1.5,'Color','yellow')
ax = gca;
ax.YAxis(2).Color = 'black';
ylim([0,1])
yl = ylabel('p(h)');
set(yl,'FontName',fName,'FontSize',fSize);
set(gcf,'paperunits','inches')
set(gcf,'papersize',pSize1)
set(gcf,'PaperPosition',pPosition1)
print('-dpdf','-r600' ,'figA17_model_worsen.pdf')
close