capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Merge ZIP-quarter collapsed 831 files to public ZIP data
Input: 
	nearest_time_driving_quarterly_2000 (created from office locations and GIS, located in folder ../offices/data/zip)
	fo_formerge (created from office locations and GIS, located in folder ../offices/data/zip)
	collapse_zipappall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
*/

use "`data'\nearest_time_driving_quarterly_2000.dta", clear;


/* ******************* */
/* **** DATA PREP **** */
/* ******************* */

keep zipcode zipcodecat statecode year quarter office1 time_driving1 office2 time_driving2 office3 time_driving3
	close_first post_first close_second post_second close_third post_third
	nbr1* nbr2*
	Population poverty_rate median_income white black hispanic age* hs_drop hs_grad some_college single married;

rename zipcode zip;
rename zipcodecat zipcat;
rename Population c_pop;
rename poverty_rate c_povrate;
rename median_income c_medinc;
rename white c_racew;
rename black c_raceb;
rename hispanic c_raceh;
rename age0to19 c_age0to19;
rename age20to44 c_age20to44;
rename age45to64 c_age45to64;
rename hs_drop c_edhsdrop;
rename hs_grad c_edhsgrad;
rename some_college c_edsomec;
rename single c_maritalnever;
rename married c_maritalmar;

/* Population of the service area of the FO closest to ZIP */
gen qtryear=yq(year, quarter);
preserve;
collapse (sum) c_pop, by(office1 qtryear);
rename c_pop c_fopop;
reshape wide c_fopop, i(office1) j(qtryear);
foreach var of varlist c_* {;
	replace `var'=0 if `var'==.;
};
reshape long c_fopop, i(office1) j(qtryear);
save "`data'\nearest_final_qtr_officepop_formerge_driving.dta", replace;
restore;
merge m:1 office1 qtryear using "`data'\nearest_final_qtr_officepop_formerge_driving.dta", keepusing(c_fopop);
drop if _merge==2; /* Offices that close are never an office1 after they close, so they don't merge back into main dataset */
drop _merge;
drop qtryear;


/* **************************** */
/* **** CLASSIFY ZIP CODES **** */
/* **************************** */

preserve;

keep zip office1 nbr1no_first nbr1no_second nbr1no_third;
foreach type in office1 nbr1no_first nbr1no_second nbr1no_third {;
	merge m:1 `type' using "`data'\fo_formerge.dta", keepusing(`type'_cls);
	keep if _merge==1 | _merge==3;
	drop _merge;
	replace `type'_cls=0 if `type'==.;
};

/* Collapse by ZIP */
collapse (max) office1_cls nbr1no_first_cls nbr1no_second_cls nbr1no_third_cls, by(zip);
save "`data'\zip_collapse_type_driving.dta", replace;
pause;

restore;
merge m:1 zip using "`data'\zip_collapse_type_driving.dta";
drop _merge;

foreach var in office1_cls nbr1no_first_cls nbr1no_second_cls nbr1no_third_cls {;
	tab `var';
};

save "`data'\zip_for831merge_qtr_driving.dta", replace;

log close;
