capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Stack closing sets
Input: 
	zip_for831merge_qtr (from AEJ_PREP_831_1)
*/

use "`data'\zip_for831merge_qtr.dta", clear;

local pre "14";
local post "8";

/* ********************************************* */
/* **** CREATE ONE DATASET FOR EACH CLOSING **** */
/* ********************************************* */

/* Identify which closing each ZIP is affected by */
gen cset1=.;
gen cset2=.;
gen cset3=.;
foreach i in 
	8	11	13	14	22	44	56	98	116	123	137	148	150	152	155	171	173	177	181	229	
	234	318	322	363	365	411	414	503	532	570	656	677	678	680	686	696	709	725	734	749	
	755	770	808	813	826	892	935	954	959	972	980	988	1002	1004	1013	1028	
	1033	1035	1040	1041	1043	1053	1061	1067	1071	1087	
	1088	1092	1102	1109	1112	1114	1118	1119	1130	1131	
	1132	1137	1141	1143	1147	1154	1157	1163	1167	1179	
	1185	1186	1188	1193	1197	1201	1202	1203	1205	1209	
	1222	1232	1238	1240	1248	1257	1261	1289	1290	1291	
	1296	1297	1299	1304	1318	1320	1321	1322	1327	1329	
	1330	1332	1339	1340	1341	1347	1350	1351
	{;	
		gen byte cset_`i'=(	nbr1no_first==`i' | nbr1no_second==`i' | nbr1no_third==`i' | 
							nbr2no_first==`i' | nbr2no_second==`i' | nbr2no_third==`i');
		replace cset1=`i' if cset1==. & cset_`i'==1;
		replace cset2=`i' if cset1!=. & cset1!=`i' & cset2==. & cset_`i'==1;
		replace cset3=`i' if cset1!=. & cset1!=`i' & cset2!=. & cset2!=`i' & cset3==. & cset_`i'==1;
		drop cset_*;
	};
forval i=1(1)3 {;
	tab cset`i', m;
};

/* Calculate date at which closing occurs */
gen qtryear=yq(year, quarter);
forval i=1(1)3{;
	egen temp`i'=min(qtryear) if 
		(nbr1no_first==cset`i' & nbr1post_first==1) |
		(nbr1no_second==cset`i' & nbr1post_second==1) |
		(nbr1no_third==cset`i' & nbr1post_third==1) |
		(nbr2no_first==cset`i' & nbr2post_first==1) |
		(nbr2no_second==cset`i' & nbr2post_second==1) |
		(nbr2no_third==cset`i' & nbr2post_third==1)
		, by(zip);
	egen csetdate`i'=max(temp`i'), by(zip);
};
drop temp1 temp2 temp3;
tab csetdate1, m;
tab csetdate2, m;
tab csetdate3, m;

/* For ZIPs affected by more than one closing, order the closings chronologically */
forval i=1(1)3 {;
	rename cset`i' old_cset`i';
	rename csetdate`i' old_csetdate`i';
};

	egen csetdate1=rowmin(old_csetdate1 old_csetdate2 old_csetdate3);

	egen csetdate3=rowmax(old_csetdate1 old_csetdate2 old_csetdate3)
		if old_csetdate1!=. & old_csetdate2!=. & old_csetdate3!=.;

	egen csetdate2=rowmax(old_csetdate1 old_csetdate2) if old_csetdate1!=. & old_csetdate2!=. & old_csetdate3==.;
	forval i=1(1)3 {;
	replace csetdate2=old_csetdate`i' if csetdate1!=old_csetdate`i' & csetdate3!=old_csetdate`i' 
		& old_csetdate1!=. & old_csetdate2!=. & old_csetdate3!=.;
	};

forval i=1(1)3 {;
	gen cset`i'=old_cset1 if csetdate`i'==old_csetdate1;
	replace cset`i'=old_cset2 if csetdate`i'==old_csetdate2;
	replace cset`i'=old_cset3 if csetdate`i'==old_csetdate3;
};

tab csetdate1, m;
tab csetdate2, m;
tab csetdate3, m;
gen csetdate_12diff=csetdate2-csetdate1;
gen csetdate_23diff=csetdate3-csetdate2;
tab csetdate_12diff, m;
tab csetdate_23diff, m;
assert csetdate1<=csetdate2 if csetdate2!=.;
assert csetdate2<=csetdate3 if csetdate3!=.;
drop old_*;

/* For ZIPs with more than one closing (see above for pre- and post-period):
if <`post' quarters apart, drop both
if >`post' and <`pre' apart, keep 1 and trim 2
if >`pre', keep both
*/
foreach i in 
	8	11	13	14	22	44	56	98	116	123	137	148	150	152	155	171	173	177	181	229	
	234	318	322	363	365	411	414	503	532	570	656	677	678	680	686	696	709	725	734	749	
	755	770	808	813	826	892	935	954	959	972	980	988	1002	1004	1013	1028	
	1033	1035	1040	1041	1043	1053	1061	1067	1071	1087	
	1088	1092	1102	1109	1112	1114	1118	1119	1130	1131	
	1132	1137	1141	1143	1147	1154	1157	1163	1167	1179	
	1185	1186	1188	1193	1197	1201	1202	1203	1205	1209	
	1222	1232	1238	1240	1248	1257	1261	1289	1290	1291	
	1296	1297	1299	1304	1318	1320	1321	1322	1327	1329	
	1330	1332	1339	1340	1341	1347	1350	1351
	{;	
		gen byte drop_cset`i'=
		(
		(cset1==`i' & csetdate_12diff<`post' & csetdate_12diff!=.) | 
		(cset2==`i' & csetdate_12diff<`post' & csetdate_12diff!=.) |
		(cset2==`i' & csetdate_12diff>=`post' & csetdate_12diff<`pre' & qtryear<=csetdate1) |
		(cset2==`i' & csetdate_23diff<`post' & csetdate_23diff!=.) | 
		(cset3==`i' & csetdate_23diff<`post' & csetdate_23diff!=.) |
		(cset3==`i' & csetdate_23diff>=`post' & csetdate_23diff<`pre' & qtryear<=csetdate2)
		);
		tab drop_cset`i';
	};

order zip year quarter qtryear cset1 csetdate1 cset2 csetdate2 cset3 csetdate3 nbr1* nbr2* ;

/* Create closing set: ZIPs affected by closing (treatment) plus ZIPs that have closing more than `post' years later (control) */
foreach i in 
		8	11	13	14	22	44	56	98	116	123	137	148	150	152	155	171	173	177	181	229	
		234	318	322	363	365	411	414	503	532	570	656	677	678	680	686	696	709	725	734	749	
		755	770	808	813	826	892	935	954	959	972	980	988	1002	1004	1013	1028	
		1033	1035	1040	1041	1043	1053	1061	1067	1071	1087	
		1088	1092	1102	1109	1112	1114	1118	1119	1130	1131	
		1132	1137	1141	1143	1147	1154	1157	1163	1167	1179	
		1185	1186	1188	1193	1197	1201	1202	1203	1205	1209	
		1222	1232	1238	1240	1248	1257	1261	1289	1290	1291	
		1296	1297	1299	1304	1318	1320	1321	1322	1327	1329	
		1330	1332	1339	1340	1341	1347	1350	1351
		{;	
		preserve;
		
		/* Get the closing date for that closing */
		gen temp1=csetdate1 if cset1==`i';
		egen csetdate`i'_temp1=max(temp1);
		gen temp2=csetdate2 if cset2==`i';
		egen csetdate`i'_temp2=max(temp2);
		gen temp3=csetdate3 if cset3==`i';
		egen csetdate`i'_temp3=max(temp3);
		
		gen csetdate`i'=csetdate`i'_temp1;
		replace csetdate`i'=csetdate`i'_temp2 if csetdate`i'==.;
		replace csetdate`i'=csetdate`i'_temp3 if csetdate`i'==.;
		
		drop temp1 temp2 temp3 csetdate`i'_temp1 csetdate`i'_temp2 csetdate`i'_temp3;
		
		/* Keep treatment ZIPs and control ZIPs with closing event after post-period ends (see above for definition) */
		gen byte treat=(cset1==`i' | cset2==`i' | cset3==`i');
		gen byte cntrl=(cset1!=`i' & cset2!=`i' & cset3!=`i' & cset1!=. 
			& csetdate1>csetdate`i'+`post' & csetdate2>csetdate`i'+`post' & csetdate3>csetdate`i'+`post');
		keep if treat==1 | cntrl==1;
		drop if drop_cset`i'==1;
		gen cset=`i';
		rename cset1 closing;
		
		/* Create event month-years */
		gen eqtryear=qtryear-csetdate`i';
		keep if eqtryear>=-`pre' & eqtryear<=`post';
		rename csetdate`i' csetdate;
		order zip eqtryear cntrl treat csetdate closing csetdate1 cset2 csetdate2 cset3 csetdate3 nbr1* nbr2*;
		keep zip eqtryear quarter year qtryear cntrl treat csetdate closing nbr1* nbr2* office1
			/*county*/ statecode cset c_*;
		tempfile cset`i' ;
		save `cset`i'' ;
		restore;
	};

/* ************************** */
/* **** APPEND DATASETS **** */
/* ************************* */
use `cset8', clear;
foreach i in 
		/*8*/	11	13	14	22	44	56	98	116	123	137	148	150	152	155	171	173	177	181	229	
		234	318	322	363	365	411	414	503	532	570	656	677	678	680	686	696	709	725	734	749	
		755	770	808	813	826	892	935	954	959	972	980	988	1002	1004	1013	1028	
		1033	1035	1040	1041	1043	1053	1061	1067	1071	1087	
		1088	1092	1102	1109	1112	1114	1118	1119	1130	1131	
		1132	1137	1141	1143	1147	1154	1157	1163	1167	1179	
		1185	1186	1188	1193	1197	1201	1202	1203	1205	1209	
		1222	1232	1238	1240	1248	1257	1261	1289	1290	1291	
		1296	1297	1299	1304	1318	1320	1321	1322	1327	1329	
		1330	1332	1339	1340	1341	1347	1350	1351
	{;
		append using `cset`i'';
	};
	
save "`data'\zip_for831_FNqtrnbr_append.dta", replace;
tab eqtryear, m;

log close;
