capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Merge 831 data into main dataset
Input: 
	zip_for831_eventstudyqtr_append (from AEJ_PREP_831_2ESTUDYQTR)
	zip_for831_eventstudyqtrnbr_append (from AEJ_PREP_831_2ESTUDYQTRNBR)
	collapse_zipappall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	collapse_zipfinall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	waittime_formerge_qtr (from AEJ_PREP_WAIT)
	nearest_final_qtr_officeapp_formerge (created from SSA data, located in folder ../offices/data/zip)
	nearest_alltravel_quarterly_2000 (created from SSA data, located in folder ../offices/data/zip)
*/

/* Append closing ZIPs and neighboring ZIPs */
use "`data'\zip_for831_eventstudyqtr_append.dta", clear;
keep zip eqtryear quarter year qtryear csetdate office1 office2 statecode cset;
gen byte cls=1;
append using "`data'\zip_for831_eventstudyqtrnbr_append.dta"; 
drop close_first post_first distance1 distance2 office3 distance3 nbr* c_*;
gen byte nbr=(cls==.);
replace cls=0 if cls==.; 
summ cls nbr;

/* Drop any neighbor ZIPs that are also closing ZIPs since xtivreg2 doesn't allow panel variable to be repeated across clusters */
preserve;
collapse nbr, by(zip);
tab nbr, m;
gen byte drop=(nbr!=0 & nbr!=1);
tempfile nbr ;
save `nbr';
restore;
merge m:1 zip using `nbr', keepusing(drop);
drop if nbr==1 & drop==1;
drop _merge drop;

local pre "20";
local post "8";

/* *********************************************** */
/* **** MERGE IN 831 DATA FOR VARIOUS GROUPS ***** */
/* *********************************************** */

/* Merge in 831 application data */
merge m:1 zip year quarter using "`data'\collapse_zipappall_qtr.dta", keepusing(all_a_ctnum all_a_daysproc);
drop if _merge==2;
gen byte from_831all_ayes=(_merge==3);
gen byte from_831all_ano=(_merge==1);
drop _merge;
replace all_a_ctnum=0 if from_831all_ayes==0;

/* Merge in 831 final allowance data */
merge m:1 zip year quarter using "`data'\collapse_zipfinall_qtr.dta", keepusing(all_r_ctnum);
drop if _merge==2;
gen byte from_831all_ryes=(_merge==3);
gen byte from_831all_rno=(_merge==1);
drop _merge;
replace all_r_ctnum=0 if from_831all_ryes==0;

/* Merge in wait time data for office1 */
merge m:1 office1 year quarter using "`data'\waittime_formerge_qtr.dta", keepusing(waitno_avg);
drop if _merge==2;
gen byte from_wait=(_merge==3);
drop _merge;
tab from_wait, m;

/* Merge in wait time for office2 */
merge m:1 office2 year quarter using "`data'\waittime_formerge_qtr.dta", keepusing(waitno_avg2);
drop if _merge==2;
gen byte from_wait2=(_merge==3);
drop _merge;
tab from_wait2, m;

/* Merge in processing time data for office1 */
merge m:1 office1 qtryear using "`data'\nearest_final_qtr_officeapp_formerge.dta", keepusing(foproc_4qtr numprocgt40_4qtr);
drop if _merge==2;
gen byte from_proc=(_merge==3);
drop _merge;
tab from_proc, m;

/* Merge in wait time for office2 */
merge m:1 office2 qtryear using "`data'\nearest_final_qtr_officeapp_formerge.dta", keepusing(foproc_4qtr2 numprocgt40_4qtr2);
drop if _merge==2;
gen byte from_proc2=(_merge==3);
drop _merge;
tab from_proc2, m;

/* Merge in travel time data */
rename zip zipcode;
merge m:1 zipcode year quarter using "`data'\nearest_alltravel_quarterly_2000.dta",
	keepusing(time_driving1 time_driving2 dist_driving1 dist_driving2 time_transit1 time_transit2);
drop if _merge==2;
drop _merge;
rename zipcode zip;

/* Create variables for wait time, processing time, and distance of office2 in quarter before closing */
tab csetdate, m;
tab qtryear, m;

gen temp_wait2=waitno_avg2 if qtryear==csetdate-1 ;
egen office2_wait=max(temp_wait2), by(zip) ;
gen temp_wait1=waitno_avg if qtryear==csetdate-1 ;
egen office1_wait=max(temp_wait1), by(zip) ;
gen office2_waitdiff=office2_wait-office1_wait if cls==1 ;
replace office2_waitdiff=0 if nbr==1 ;

gen temp_proc2=foproc_4qtr2 if qtryear==csetdate-1 ;
egen office2_proc=max(temp_proc2), by(zip) ;
gen temp_proc1=foproc_4qtr if qtryear==csetdate-1 ;
egen office1_proc=max(temp_proc1), by(zip) ;
gen office2_procdiff=office2_proc-office1_proc if cls==1 ;
replace office2_procdiff=0 if nbr==1 ;

gen temp_numproc2=numprocgt40_4qtr2 if qtryear==csetdate-1 ;
egen office2_numproc40=max(temp_numproc2), by(zip) ;
gen temp_numproc1=numprocgt40_4qtr if qtryear==csetdate-1 ;
egen office1_numproc40=max(temp_numproc1), by(zip) ;
gen office2_numproc40diff=office2_numproc-office1_numproc if cls==1 ;
replace office2_numproc40diff=0 if nbr==1 ;

gen temp_dist1=dist_driving1 if qtryear==csetdate-1 ;
egen office1_dist=max(temp_dist1), by(zip) ;
gen temp_dist2=dist_driving2 if qtryear==csetdate-1 ;
egen office2_dist=max(temp_dist2), by(zip) ;
gen office2_distdiff=office2_dist-office1_dist if cls==1 ;
replace office2_distdiff=0 if nbr==1 ;

drop temp_*;
count;
count if waitno_avg2!=.;
count if waitno_avg!=.;
count if office2_wait!=.;
count if office1_wait!=.;
count if office2_waitdiff!=.;
count if foproc_4qtr2!=.;
count if foproc_4qtr!=.;
count if office2_proc!=.;
count if office1_proc!=.;
count if office2_procdiff!=.;
count if office2_numproc40!=.;
count if office1_numproc40!=.;
count if office2_numproc40diff!=.;
count if dist_driving2!=.;
count if dist_driving1!=.;
count if office2_dist!=.;
count if office1_dist!=.;
count if office2_distdiff!=.;

summ office2_*, det;


/* ************************ */
/* **** DEFINE SAMPLES **** */
/* ************************ */

preserve;
keep if eqtryear<0;

foreach stub in all {;
	egen byzip`stub'_nomatch=total(from_831`stub'_ano), by(zip);
	egen byzip`stub'_count=count(from_831`stub'_ano), by(zip);
	gen byzip`stub'_propno=byzip`stub'_nomatch/byzip`stub'_count;
	egen byzip`stub'_maxapp=max(`stub'_a_ctnum), by(zip);
	egen byzip`stub'_meanapp=mean(`stub'_a_ctnum), by(zip);
};

collapse byzip*, by(zip);

foreach stub in all {;
	tab byzip`stub'_nomatch, m;
};

foreach stub in all {;
	summ byzip`stub'_propno, det;
};

/* Max number of applications, by ZIP */
foreach stub in all {;
	tab byzip`stub'_maxapp, m;
	tab byzip`stub'_maxapp if byzip`stub'_nomatch>0 & byzip`stub'_nomatch!=., m;
	summ byzip`stub'_maxapp;
	summ byzip`stub'_maxapp if byzip`stub'_nomatch>0 & byzip`stub'_nomatch!=.;
};

/* Mean number of applications, by ZIP */
foreach stub in all {;
	summ byzip`stub'_meanapp;
	summ byzip`stub'_meanapp if byzip`stub'_nomatch>0 & byzip`stub'_nomatch!=.;
};

/* Define samples for each group, keeping only ZIPs that get enough applications BEFORE closing event*/
gen byte sample_all=(byzipall_meanapp>3 & byzipall_meanapp!=.);

tempfile dropzip ;
save `dropzip' ;
restore;

merge m:1 zip using `dropzip', keepusing(sample*);
drop _merge;

foreach var of varlist sample* {;
	tab `var', m;
};

save "`data'\zip_for831_eventstudy_clsnbriv_forreg.dta", replace;
