capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Regressions for Figures A.11, A.15
Input:
	zip_for831_FNqtrnbr_forreg
*/

use "`data'\zip_for831_FNqtrnbr_forreg.dta", clear; (from AEJ_PREP_831_3QTRNBR)

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;


/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

forval eqtryear=-`=scpre'(1)`=scpost' {;
	gen byte eqtryear_`=`eqtryear'+`=scpre''=(eqtryear==`eqtryear');
};

forval eqtryear=-`=scpre'(1)`=scpost' {;
	gen trtXeqtryear_`=`eqtryear'+`=scpre''=treat*eqtryear_`=`eqtryear'+`=scpre'';
};

summ eqtryear_*;
drop eqtryear_*;
summ trtXeqtryear_*;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	gen `stub'_a_lvlnum=`stub'_a_ctnum;
	gen `stub'_r_lvlnum=`stub'_r_ctnum;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* StateXyear fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ********************************** */
/* **** YEAR-BY-YEAR REGRESSIONS **** */
/* ********************************** */

/* Figure A.11: applicants and recipients */
foreach stub in all {;
	foreach type in a r {;
	foreach var of varlist 
		`stub'_`type'_ctnum
		{;
		xi: statsby _b _se, saving("`data'\statsby\FNreg_qtrnbr_`date'_`var'wt.dta", replace):
			areg `var' 
				trtXeqtryear_0-trtXeqtryear_`=`pre'-3' trtXeqtryear_`=`pre'-1'-trtXeqtryear_`=`pre'+`post''  
				treat i.eqtryear i.stateXyear i.quarter
				if sample_`stub'==1
				[aweight=weight_`type'_`stub']
			, absorb(zip) vce(cluster closing);
	};
};
};

/* Figure A.15: wait time and processing time*/
foreach stub in waitno {;
	xi: statsby _b _se, saving("`data'\statsby\FNreg_qtrnbr_`date'_`stub'_avgwt.dta", replace):
		areg `stub'_avg 
			trtXeqtryear_0-trtXeqtryear_`=`pre'-3' trtXeqtryear_`=`pre'-1'-trtXeqtryear_`=`pre'+`post'' 
			treat i.eqtryear i.stateXyear i.quarter 
			if qtryear>=yq(2004,4) & sample_all==1
			[aweight=weight_`stub']
		, absorb(zip) vce(cluster closing);
};

foreach stub in all_a_daysproc {;
	xi: statsby _b _se, saving("`data'\statsby\FNreg_qtrnbr_`date'_`stub'wt.dta", replace):		
		areg `stub' 
			trtXeqtryear_0-trtXeqtryear_`=`pre'-3' trtXeqtryear_`=`pre'-1'-trtXeqtryear_`=`pre'+`post'' 
			treat i.eqtryear i.stateXyear i.quarter  
			if sample_all==1
			[aweight=weight_a_all]
		, absorb(zip) vce(cluster closing);	
	};
