capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Regressions for Figure 5 RHS
Input:
	zip_for831_tradcontrolqtr_forreg (from AEJ_PREP_831_3TRADDD)
*/ 

local pre "12";

/* ************************************************* */
/* **** TRADITIONAL DD (INCLUDES CONTROL GROUP) **** */
/* ************************************************* */

/* Prep for regressions */
use "`data'\zip_for831_tradcontrolqtr_forreg.dta", clear;

/* Event year dummies (set event quarter at -2 for control group) */
replace eqtryear = -2 if cntrl == 1 ;
tab eqtryear, m ;
forval eqtryear=-`=scpre'(1)8 {;
	gen byte eqtryear_`=`eqtryear'+`=scpre''=(eqtryear==`eqtryear');
};
summ eqtryear_*;

/* Create weights for wait time and characteristics regs */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	gen `stub'_a_lvlnum=`stub'_a_ctnum;
	gen `stub'_r_lvlnum=`stub'_r_ctnum;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'<=0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* Log population */
gen log_cty_pop=log(cty_pop);

/* Keep selected quarters */
tab eqtryear, m;
keep if cntrl==1 | (treat==1 & eqtryear >= -`pre' & eqtryear <= 8);
tab eqtryear, m;

/* Limit control time frame to same as treat time frame */
summ qtryear if treat ;
local trt_min = r(min) ;
summ qtryear if cntrl ;
drop if cntrl==1 & qtryear<`trt_min' ;

/* Use only control ZIPs that are within a small radius of an office */
drop if cntrl==1 & distance1>20 ;
	
/* Recode states and years to add stateXyear fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;

/* Verify that regression includes both controls and treated */
summ treat cntrl all_a_ctnum eqtryear_* if sample_all==1 ;

/* Year by year regressions */
gen byte weight_lvl = 1 ;
local weight_all_a_ctnum  	"weight_a_all";
local weight_all_r_ctnum  	"weight_r_all";
local weight_all_a_lvlnum 	"weight_lvl";
local weight_all_r_lvlnum 	"weight_lvl";

foreach type in a r {;
	foreach stub in ctnum lvlnum {;
		xi: statsby _b _se, saving("`data'\statsby\DDreg_qtr_`date'_all_`type'_`stub'wt.dta", replace):
			areg all_`type'_`stub' 
				eqtryear_0-eqtryear_`=`pre'-3' eqtryear_`=`pre'-1'-eqtryear_`=8+`pre'' 
				i.stateXyear i.quarter
				if sample_all==1 
				[aweight=`weight_all_`type'_`stub'']
			, absorb(zip) vce(cluster zip);
	};
};

	/* Pre-post regressions and point estimates */
	
	local var_wout "post qtrzero" ;
	local var_with "post qtrzero t" ;
	
	/* Pre/post dummies */
	gen byte post=(eqtryear>0);
	gen byte qtrzero=(eqtryear==0);

	/* Event time trend (set to zero for control) */
	summ eqtryear;
	local min = r(min);
	gen t = eqtryear - `min' if treat == 1;
	replace t = 0 if cntrl == 1;
	tab t, m;

	/* Starter */
	xi: areg all_a_ctnum
			post qtrzero
			if sample_all==1
		, absorb(zip) vce(cluster zip);
	outreg2 using "`output'\DDreg_qtr_`date'_wout.xls", replace;
	outreg2 using "`output'\DDreg_qtr_`date'_with.xls", replace;

	foreach time in wout with {;
		foreach type in a r {;
			foreach stub in ctnum lvlnum {;
				xi: areg all_`type'_`stub' 
						`var_`time''
						i.stateXyear i.quarter  
						if sample_all==1 
						[aweight=`weight_all_`type'_`stub'']
					, absorb(zip) vce(cluster zip);
				outreg2 using "`output'\DDreg_qtr_`date'_`time'.xls", append;
			};
		};
	};
