capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause on
# delimit;

local output "";
local log "";
local data "";
local area "";

/* 
Prep area code calls to 800 number
Input: 
	combined2000_2010_fipsareacode (created from SSA data, located in folder ../offices/data/facilities)
	nearest_final_2000_2014 (created from SSA data, located in folder ../offices/data/zip)
	areacode_zipunique (created from public-use data, located in folder ../offices/data/facilities)
	areacode_forstata (provided by SSA Office of Customer Service, located in folder ../offices/data/facilities)
*/

/* Eliminate duplicate ZIP codes */
use "`area'\combined2000_2010_fipsareacode.dta", clear;
duplicates report zipcode;
duplicates drop zipcode, force;
save "`area'\areacode_zipunique.dta", replace;

use "`data'\nearest_final_2000_2014.dta", replace;

/* Identify which closing each ZIP is affected by */
gen cset=.;
foreach i in 
	98 137 411 532 570 826 959 972 1043 1109 1118 1163 1201 1209 1297
	{;	
		gen byte temp_`i'=(office1==`i');
		egen cset_`i'=max(temp_`i'), by(zipcode);
		replace cset=`i' if cset==. & cset_`i'==1;
		drop temp_*;
		drop cset_*;
	};
tab cset, m;

/* Calculate date at which closing occurs */
gen moyear=ym(year, month);
egen temp=max(moyear) if office1==cset, by(zipcode);
egen csetdate=max(temp), by(zipcode);
drop temp;
tab csetdate, m;

/* Collapse to ZIP level; merge in area code data */
rename closebefore2014 pre2014;
collapse cset csetdate pre2014, by(zipcode);
merge m:1 zipcode using "`area'\areacode_zipunique.dta", keepusing(areacode);
drop if _merge==2;
drop _merge;
gen byte treat_zip=(cset!=.);
drop if areacode==.;

/* Collapse to area code */
collapse (mean) treat_zip cset csetdate pre2014, by(areacode);
tab treat_zip, m; 
tab cset, m;
tab pre2014, m;
gen byte treat=(treat_zip>0);
gen byte cntrl=(pre2014>0 & !treat);

/* Expand to get areacode by month and year */
expand 28;
by areacode, sort: gen month=_n;
gen year=2014 if month>=1 & month<=12;
replace year=2015 if month>=13 & month<=24;
replace year=2016 if month>=25;
replace month=month-12 if month>=13 & month<=24;
replace month=month-24 if month>=25;

/* Merge in call volume */
merge 1:1 areacode year month using "`area'\areacode_forstata.dta", keepusing(call_count);

preserve;
keep if _merge==2;
collapse (count) month, by(areacode);
rename month count;
save "`area'\areacode_unmatched.dta", replace;
restore;

drop if _merge==2;
drop _merge;

save "`data'\areacode_FN_forreg.dta", replace;

