capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause on
# delimit;

local output "";
local log "";
local data "";
local wait "";

/* 
Prep wait time data
Input: 
	waittime_prep (provided by Office of Public Service and Operations Support, 
			located in folder ../offices/data/wait)
*/

use "`wait'\waittime_prep.dta", clear;
describe;

order waitno_tot_* waitno_count_* waitno_avg_* waitap_tot_* waitap_count_* waitap_avg_*;

drop if office_number==.;
reshape long waitno_tot_ waitno_count_ waitno_avg_ waitap_tot_ waitap_count_ waitap_avg_, 
	i(office_number) j(date) string;

foreach stub in
	waitno_tot waitno_count waitno_avg waitap_tot waitap_count waitap_avg {;
		rename `stub'_ `stub';
	};
	
gen year=substr(date,1,4);
destring year, replace;
gen month=substr(date,6,2);
destring month, replace;
gen quarter=1 if month==1 | month==2 | month==3;
replace quarter=2 if month==4 | month==5 | month==6;
replace quarter=3 if month==7 | month==8 | month==9;
replace quarter=4 if month==10 | month==11 | month==12;
gen moyear=ym(year,month);
gen qtryear=yq(year,quarter);
drop date;
order office_number year month quarter moyear qtryear;
rename office_number office1;

/* Create variables for total waiting time */
gen wait_tot=waitno_tot+waitap_tot;
gen wait_count=waitno_count+waitap_count;
gen wait_avg=wait_tot/wait_count;
summ wait*;

save "`data'\waittime_formerge_mo.dta", replace;

/* Collapse to quarter level */
preserve;
collapse (sum) waitno_tot waitno_count waitap_tot waitap_count wait_tot wait_count, by(office1 year quarter qtryear);
gen waitno_avg=waitno_tot/waitno_count;
gen waitap_avg=waitap_tot/waitap_count;
gen wait_avg=wait_tot/wait_count;
summ wait*;

gen office2=office1;
gen waitno_avg2=waitno_avg;

save "`data'\waittime_formerge_qtr.dta", replace;

/* Wait time by year */
restore;
collapse (sum) waitno_tot waitno_count waitap_tot waitap_count wait_tot wait_count, by(office1 year);
gen waitno_avg=waitno_tot/waitno_count;
gen waitap_avg=waitap_tot/waitap_count;
gen wait_avg=wait_tot/wait_count;
summ wait*;
save "`data'\waittime_formerge_yr.dta", replace;
