capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Summary statistics for Table 1
Input: 
	nearest_final_quarterly_2000 (created from office locations and GIS, located in folder ../offices/data/zip)
	fo_formerge (created from office locations and GIS, located in folder ../offices/data/zip)
	collapse_zipappall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	waittime_formerge_qtr (from AEJ_PREP_WAIT)
*/

use "`data'\nearest_final_quarterly_2000.dta", clear;

/* ******************* */
/* **** DATA PREP **** */
/* ******************* */

keep zipcode zipcodecat statecode year quarter office1 distance1 office2 distance2 office3 distance3
	close_first post_first close_second post_second close_third post_third
	nbr1* nbr2*
	Population poverty_rate median_income male white black asian hispanic age0to19 age20to44 age45to64
	hs_drop hs_grad some_college single married;

rename zipcode zip;
rename zipcodecat zipcat;
rename Population c_pop;
rename poverty_rate c_povrate;
rename median_income c_medinc;
rename male c_male;
rename white c_racew;
rename black c_raceb;
rename hispanic c_raceh;
rename age0to19 c_age0to19;
rename age20to44 c_age20to44;
rename age45to64 c_age45to64;
rename hs_drop c_edhsdrop;
rename hs_grad c_edhsgrad;
rename some_college c_edsomec;
rename single c_maritalnever;
rename married c_maritalmar;

/* Missing categories */
replace c_povrate=c_povrate/100;
gen c_female=1-c_male;
gen c_raceo=1-c_racew-c_raceb-c_raceh;
gen c_age65plus=1-c_age0to19-c_age20to44-c_age45to64;
gen c_edcoll=1-c_edhsdrop-c_edhsgrad-c_edsomec;
gen c_maritalprev=1-c_maritalnever-c_maritalmar;

order 
zip zip statecode year quarter office1 distance1 office2 distance2 office3 distance3
close_first post_first close_second post_second close_third post_third
nbr1* nbr2*
c_pop c_povrate c_medinc c_male c_female c_racew c_raceb c_raceh c_raceo c_age0to19 c_age20to44 c_age45to64 c_age65plus
c_edhsdrop c_edhsgrad c_edsomec c_edcoll c_maritalnever c_maritalmar c_maritalprev;

/*Classify ZIPs as closing or neighboring */
preserve;

keep zip office1 nbr1no_first nbr1no_second nbr1no_third;
foreach type in office1 nbr1no_first nbr1no_second nbr1no_third {;
	merge m:1 `type' using "`data'\fo_formerge.dta", keepusing(`type'_cls);
	keep if _merge==1 | _merge==3;
	drop _merge;
	replace `type'_cls=0 if `type'==.;
};

/* Collapse by ZIP */
collapse (max) office1_cls nbr1no_first_cls nbr1no_second_cls nbr1no_third_cls, by(zip);
save "`data'\zip_collapse_type.dta", replace;

restore;
merge m:1 zip using "`data'\zip_collapse_type.dta";
drop if _merge==2;
drop _merge;


/* ****************************************** */
/* **** MERGE IN APPS AND WAIT TIME DATA **** */
/* ****************************************** */

/* Merge in 831 application data */
merge m:1 zip year quarter using "`data'\collapse_zipappall_qtr.dta", keepusing(all_a_ctnum);
drop if _merge==2;
gen byte from_831all_ayes=(_merge==3);
gen byte from_831all_ano=(_merge==1);
replace all_a_ctnum=0 if from_831all_ayes==0;
drop _merge;

/* Merge in wait time data */
merge m:1 office1 year quarter using "`data'\waittime_formerge_qtr.dta", keepusing(waitno_avg);
drop if _merge==2;
gen byte from_wait=(_merge==3);
drop _merge;
tab from_wait, m;


/* ************************************** */
/* **** CALCULATE SUMMARY STATISTICS **** */
/* ************************************** */
sort zip year quarter;

/* Classify comparison ZIPs */
foreach gp in office1_cls nbr1no_first_cls nbr1no_second_cls nbr1no_third_cls {;
	tab `gp', m;
};
gen byte closed=(office1_cls==1);
gen byte nbr=(!closed & nbr1no_first_cls==1 | nbr1no_second_cls==1 | nbr1no_third_cls==1);
gen byte comp=(!closed & !nbr);
foreach gp in closed nbr comp {;
	tab `gp', m;
};
gen group=1 if closed==1;
replace group=2 if nbr==1 & group==.;
replace group=3 if comp==1 & group==.;

gen temp_wait=waitno_avg if year==2005;
egen waitavg2005=mean(temp_wait), by(zip);
gen temp_app=all_a_ctnum if year==2000;
egen apptot2000=total(temp_app), by(zip);
egen appavg2000=mean(temp_app), by(zip);
gen byte sample_all=(appavg2000>3 & appavg2000!=.);

/* Summary statistics for all ZIPs (collapsing to get one obs per ZIP) */
preserve;
collapse 	(mean) c_* waitavg2005 appavg2000 closed nbr comp group,
			by(zip);
foreach gp in closed nbr comp {;
	tab `gp', m;
};

foreach gp in closed nbr comp {;
	summ c_* waitavg2005 appavg2000 if `gp'==1;
};

foreach var of varlist c_* waitavg2005 appavg2000{;
	ttest `var' if group==1 | group==2, by(group);
};
foreach var of varlist c_* waitavg2005 appavg2000{;
	ttest `var' if group==1 | group==3, by(group);
};
foreach var of varlist c_* waitavg2005 appavg2000{;
	ttest `var' if group==2 | group==3, by(group);
};
