capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Table 3
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

local list_r_all "all_r_ctnum all_r_ctsevmed all_r_ctsevhigh all_r_ctsevvh all_r_ctbsmental all_r_ctbsmusc all_r_ctbsphys all_r_ctedhsdrop all_r_ctedhsgrad all_r_ctedcollgrad all_r_ctage18to34 all_r_ctage35to49 all_r_ctage50plus all_r_sevmed all_r_sevhigh all_r_sevvh all_r_bsmental all_r_bsmusc all_r_bsphys all_r_ed all_r_age"; 
local list_r_diadult "diadult_r_ctnum diadult_r_ctsevmed diadult_r_ctsevhigh diadult_r_ctsevvh diadult_r_ctbsmental diadult_r_ctbsmusc diadult_r_ctbsphys diadult_r_ctedhsdrop diadult_r_ctedhsgrad diadult_r_ctedcollgrad diadult_r_ctage18to34 diadult_r_ctage35to49 diadult_r_ctage50plus"; 
local list_r_ssiadult "ssiadult_r_ctnum ssiadult_r_ctsevmed ssiadult_r_ctsevhigh ssiadult_r_ctsevvh ssiadult_r_ctbsmental ssiadult_r_ctbsmusc ssiadult_r_ctbsphys ssiadult_r_ctedhsdrop ssiadult_r_ctedhsgrad ssiadult_r_ctedcollgrad ssiadult_r_ctage18to34 ssiadult_r_ctage35to49 ssiadult_r_ctage50plus"; 
local list_r_ssikid "ssikid_r_ctnum ssikid_r_ctsevmed ssikid_r_ctsevhigh ssikid_r_ctsevvh ssikid_r_ctbsmental ssikid_r_ctbsphys ssikid_r_ctage0to9 ssikid_r_ctage10to17"; 

local list_r_all_earn "all_r_ctpearn0 all_r_ctpearn5 all_r_ctpearn15 all_r_ctpearn25 all_r_pearn";
local list_r_diadult_earn "diadult_r_ctpearn0 diadult_r_ctpearn5 diadult_r_ctpearn15 diadult_r_ctpearn25"; 
local list_r_ssiadult_earn "ssiadult_r_ctpearn0 ssiadult_r_ctpearn5 ssiadult_r_ctpearn15 ssiadult_r_ctpearn25"; 

/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ************************************************************ */
/* **** PRE-POST REGRESSIONS FOR APPLICANTS AND RECIPIENTS **** */
/* ************************************************************ */

foreach stub in all diadult ssiadult ssikid {;
	xi: areg `stub'_r_ctnum
			trtXpost trtXzero treat i.eqtryear  
			if sample_`stub'==1
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\qtr_table3_`stub'.xls", replace;
};

foreach stub in all diadult ssiadult ssikid {;
	foreach var of varlist 
		`list_r_`stub'' {;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear`i' i.quarter 
				if sample_`stub'==1
				[aweight=weight_r_`stub']
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\qtr_table3_`stub'.xls", append;
	};
};

foreach stub in all diadult ssiadult {;
	foreach var of varlist 
		`list_r_`stub'_earn' {;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter 
				if sample_`stub'==1
				[aweight=weight_r_`stub']
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\qtr_table3_`stub'.xls", append;
	};
};