capture log close
clear all
set more off
# delimit;

/* 
Cost and benefit analysis calculation for Table 6
*/



qui{; /* Suppress initial data input */
/* Matrix setup */
matrix define table6 = J(14, 9, .);		

/* Average ZIPs affected per closing */		
scalar cls_affected_zip				= 10;
scalar nbr_affected_zip				= 61;

/* Mean applicants per quarter per ZIP */
scalar cls_qrtZIP_app				= 39.7;
scalar nbr_qrtZIP_app				= 42.5;

/* Applicaiton percentage decline */
scalar cls_disc_app					= -0.100 ;	
scalar nbr_disc_app					= -0.0460;	

/* Benefit amount */
scalar di_benf						= 1300;
scalar ssiadult_benf				= 700;
scalar ssikid_benf					= 700;
scalar insurance_benf            	= 1600;

/* Probability of no insurance coverage */
scalar di_prob_noins		       	= 0.2;
scalar ssiadult_prob_noins		 	= 0.5;
scalar ssikid_prob_noins		   	= 0  ;

/* Cost of public fund */
scalar cost_public_fund				= 0.2;

/* Hourly of time and earnings decay */
scalar hrvalue						= 20;
scalar save_app_hrs				    = 40;
scalar decay_dayvalue				= 28;
scalar cls_decay_day				= 3.43;
scalar nbr_decay_day				= 1.76;

scalar cls_travel_hr				= 0.2;
scalar nbr_travel_hr				= 0;
scalar cong_hr						= 15;

scalar prob_travel		       		= 0.5;
scalar prob_cong		       		= 0.5;
scalar prob_reject		       		= 0.5;

/* Admin cost */
scalar save_cls_FO					= -4000000/10;
scalar save_admin_process			= 12000000000*(2/3)/4400000;

/* WELFARE CALCULATION */
foreach case in  MHVH HVH VH {;					 

if "`case'" == "MHVH" {;
	local j_case  = 0;
	local undeserve_on = 0;
	
	scalar cls_di_qrtZIP_rec			= 10.9;
	scalar cls_ssiadult_qrtZIP_rec		= 7.3;
	scalar cls_ssikid_qrtZIP_rec		= 3.2;
	scalar nbr_di_qrtZIP_rec			= 11.3;
	scalar nbr_ssiadult_qrtZIP_rec		= 7.7;
	scalar nbr_ssikid_qrtZIP_rec		= 3.4;

	scalar cls_di_disc_rec				= -0.148;	
	scalar cls_ssiadult_disc_rec		= -0.180;	
	scalar cls_ssikid_disc_rec			= -0.147;	
	scalar nbr_di_disc_rec				= -0.0898;	
	scalar nbr_ssiadult_disc_rec		= -0.101;	
	scalar nbr_ssikid_disc_rec			= -0.111;	
	
	scalar ud_cls_di_qrtZIP_rec			= 0;
	scalar ud_cls_ssiadult_qrtZIP_rec	= 0;
	scalar ud_cls_ssikid_qrtZIP_rec		= 0;
	scalar ud_nbr_di_qrtZIP_rec			= 0;
	scalar ud_nbr_ssiadult_qrtZIP_rec	= 0;
	scalar ud_nbr_ssikid_qrtZIP_rec		= 0;

	scalar ud_cls_di_disc_rec			= 0;	
	scalar ud_cls_ssiadult_disc_rec		= 0;	
	scalar ud_cls_ssikid_disc_rec		= 0;	
	scalar ud_nbr_di_disc_rec			= 0;	
	scalar ud_nbr_ssiadult_disc_rec		= 0;	
	scalar ud_nbr_ssikid_disc_rec		= 0;
};

if "`case'" == "HVH" {;
	local j_case  = 1;
	local undeserve_on = 1;
	
	/* H + VH */
	scalar cls_di_qrtZIP_rec			= 2.8+3.7; 
	scalar cls_ssiadult_qrtZIP_rec		= 2.9+2.2;
	scalar cls_ssikid_qrtZIP_rec		= 2.8+0.2;
	scalar nbr_di_qrtZIP_rec			= 2.9+3.8;
	scalar nbr_ssiadult_qrtZIP_rec		= 3.1+2.3;
	scalar nbr_ssikid_qrtZIP_rec		= 2.9+0.2;
	
	
	scalar cls_di_disc_rec				= (-0.121*2.8 + -0.0194*3.7)/cls_di_qrtZIP_rec;	
	scalar cls_ssiadult_disc_rec		= (-0.218*2.9 + -0.0235*2.2)/cls_ssiadult_qrtZIP_rec;
	scalar cls_ssikid_disc_rec			= (-0.138*2.8 + -0.0113*0.2)/cls_ssikid_qrtZIP_rec;	
	scalar nbr_di_disc_rec				= (-0.0864*2.9 + -0.0177*3.8)/nbr_di_qrtZIP_rec;	
	scalar nbr_ssiadult_disc_rec		= (-0.157*3.1 + 0.0245*2.3)/nbr_ssiadult_qrtZIP_rec;		
	scalar nbr_ssikid_disc_rec			= (-0.106*2.9 + -0.00684*0.2)/nbr_ssikid_qrtZIP_rec;	

	/* M: Non-deserving applicants */
	scalar ud_cls_di_qrtZIP_rec			= 4.4;
	scalar ud_cls_ssiadult_qrtZIP_rec	= 2.2;
	scalar ud_cls_ssikid_qrtZIP_rec		= 0.3;
	scalar ud_nbr_di_qrtZIP_rec			= 4.6;
	scalar ud_nbr_ssiadult_qrtZIP_rec	= 2.3;
	scalar ud_nbr_ssikid_qrtZIP_rec		= 0.3;

	scalar ud_cls_di_disc_rec			= -0.292;	
	scalar ud_cls_ssiadult_disc_rec		= -0.295;	
	scalar ud_cls_ssikid_disc_rec		= -0.0846;	
	scalar ud_nbr_di_disc_rec			= -0.169;	
	scalar ud_nbr_ssiadult_disc_rec		= -0.156;	
	scalar ud_nbr_ssikid_disc_rec		= -0.0630;
};

if "`case'" == "VH" {;
	local j_case  = 2;
	local undeserve_on = 1;
	
	/* VH */
	scalar cls_di_qrtZIP_rec			= 3.7; 
	scalar cls_ssiadult_qrtZIP_rec		= 2.2;
	scalar cls_ssikid_qrtZIP_rec		= 0.2;
	scalar nbr_di_qrtZIP_rec			= 3.8;
	scalar nbr_ssiadult_qrtZIP_rec		= 2.3;
	scalar nbr_ssikid_qrtZIP_rec		= 0.2;
	
	scalar cls_di_disc_rec				= -0.0194;	
	scalar cls_ssiadult_disc_rec		= -0.0235;
	scalar cls_ssikid_disc_rec			= -0.0113;	
	scalar nbr_di_disc_rec				= -0.0177;	
	scalar nbr_ssiadult_disc_rec		= 0.0245;		
	scalar nbr_ssikid_disc_rec			= -0.00684;	

	/* M + H: Non-deserving applicants */
	scalar ud_cls_di_qrtZIP_rec			= 4.4+2.8;
	scalar ud_cls_ssiadult_qrtZIP_rec	= 2.2+2.9;
	scalar ud_cls_ssikid_qrtZIP_rec		= 0.3+2.8;
	scalar ud_nbr_di_qrtZIP_rec			= 4.6+2.9;
	scalar ud_nbr_ssiadult_qrtZIP_rec	= 2.3+3.1;
	scalar ud_nbr_ssikid_qrtZIP_rec		= 0.3+2.9;

	scalar ud_cls_di_disc_rec			= (-0.292*4.4 + -0.121*2.8)/ud_cls_di_qrtZIP_rec;	
	scalar ud_cls_ssiadult_disc_rec		= (-0.295*2.2 + -0.218*2.9)/ud_cls_ssiadult_qrtZIP_rec;
	scalar ud_cls_ssikid_disc_rec		= (-0.0846*0.3 + -0.138*2.8)/ud_cls_ssikid_qrtZIP_rec;	
	scalar ud_nbr_di_disc_rec			= (-0.169*4.6 + -0.0864*2.9)/ud_nbr_di_qrtZIP_rec;	
	scalar ud_nbr_ssiadult_disc_rec		= (-0.156*2.3 + -0.157*3.1)/ud_nbr_ssiadult_qrtZIP_rec;
	scalar ud_nbr_ssikid_disc_rec		= (-0.0630*0.3 + -0.106*2.9)/ud_nbr_ssikid_qrtZIP_rec;	

};


local j_gamma = 1;

foreach gamma in 0.67 1.78 6.71 {;

foreach typ in cls nbr {;

foreach gp in di ssiadult ssikid {;

	scalar num_`gp'_`typ'_rec    = `typ'_affected_zip * `typ'_`gp'_qrtZIP_rec*4;
	scalar ud_num_`gp'_`typ'_rec = `typ'_affected_zip * ud_`typ'_`gp'_qrtZIP_rec*4;
	
	scalar cost_benf_`typ'_`gp'=(`gamma'*`gp'_benf*12*2)   * `typ'_`gp'_disc_rec * (num_`gp'_`typ'_rec);
	scalar cost_ins_`typ'_`gp' =(`gamma'*insurance_benf*2) * `typ'_`gp'_disc_rec * (num_`gp'_`typ'_rec * `gp'_prob_noins);

	scalar save_ud_benf_`typ'_`gp' = `undeserve_on' * (`gp'_benf*12*2*cost_public_fund)   * ud_`typ'_`gp'_disc_rec * (ud_num_`gp'_`typ'_rec);
	scalar save_ud_ins_`typ'_`gp'  = `undeserve_on' * (insurance_benf*2*cost_public_fund) * ud_`typ'_`gp'_disc_rec * (ud_num_`gp'_`typ'_rec * `gp'_prob_noins);
	
};

	scalar num_`typ'_app   = 4 * `typ'_affected_zip * `typ'_qrtZIP_app;
	scalar num_`typ'_keep  = num_`typ'_app * (1+cls_disc_app);
	scalar num_`typ'_decay = num_`typ'_keep - num_ssikid_`typ'_rec * (1+`typ'_ssikid_disc_rec);
	
	scalar cost_`typ'_cong   = num_`typ'_keep * cong_hr * hrvalue * prob_cong;
	scalar cost_`typ'_decay  = num_`typ'_decay * `typ'_decay_day * decay_dayvalue * prob_reject;
	scalar cost_`typ'_travel = num_`typ'_app * (1+`typ'_disc_app) * `typ'_travel_hr * hrvalue * prob_travel;
	
	scalar save_`typ'_admin = num_`typ'_app * `typ'_disc_app * save_admin_process;
	scalar save_`typ'_apply = num_`typ'_app * `typ'_disc_app * hrvalue * save_app_hrs;
	
};

/* COST */
matrix table6[2,`=`j_gamma'+`j_case'*3'] 
		   = -(cost_benf_cls_di + cost_benf_cls_ssiadult + cost_benf_cls_ssikid +
			   cost_ins_cls_di  + cost_ins_cls_ssiadult  + cost_ins_cls_ssikid);
					  
matrix table6[3,`=`j_gamma'+`j_case'*3'] 
		   = -(cost_benf_nbr_di + cost_benf_nbr_ssiadult + cost_benf_nbr_ssikid +
			   cost_ins_nbr_di  + cost_ins_nbr_ssiadult  + cost_ins_nbr_ssikid);
			   
matrix table6[4,`=`j_gamma'+`j_case'*3'] 
			= (cost_cls_cong + cost_cls_travel + cost_cls_decay + 
			   cost_nbr_cong + cost_nbr_travel + cost_nbr_decay);
			
matrix table6[8,`=`j_gamma'+`j_case'*3'] 	
		   = -(save_ud_benf_cls_di + save_ud_benf_cls_ssiadult + save_ud_benf_cls_ssikid +
			   save_ud_ins_cls_di  + save_ud_ins_cls_ssiadult  + save_ud_ins_cls_ssikid  +
			   save_ud_benf_nbr_di + save_ud_benf_nbr_ssiadult + save_ud_benf_nbr_ssikid +
			   save_ud_ins_nbr_di  + save_ud_ins_nbr_ssiadult  + save_ud_ins_nbr_ssikid);
	
/* BENEFIT */	  
matrix table6[9,`=`j_gamma'+`j_case'*3'] 
			= -(save_cls_admin + save_nbr_admin)*(1+cost_public_fund);
					 
matrix table6[10,`=`j_gamma'+`j_case'*3'] = -(save_cls_FO*(1+cost_public_fund));

matrix table6[11,`=`j_gamma'+`j_case'*3'] = -(save_cls_apply + save_nbr_apply);
			  
/* Calculate the cost-benefit ratio BEFORE rounding */											
matrix table6[5,`=`j_gamma'+`j_case'*3']  = table6[2,`=`j_gamma'+`j_case'*3'] + 
											table6[3,`=`j_gamma'+`j_case'*3'] +	
											table6[4,`=`j_gamma'+`j_case'*3'];	
			  
matrix table6[12,`=`j_gamma'+`j_case'*3'] = table6[8,`=`j_gamma'+`j_case'*3'] + 
											table6[9,`=`j_gamma'+`j_case'*3'] +	
											table6[10,`=`j_gamma'+`j_case'*3']+	
											table6[11,`=`j_gamma'+`j_case'*3'];	

matrix table6[14,`=`j_gamma'+`j_case'*3'] = round(table6[5,`=`j_gamma'+`j_case'*3']/table6[12,`=`j_gamma'+`j_case'*3'],0.1);
											
local j_gamma = `j_gamma' + 1;

}; /* LOOP END: CRRA */
			 					 
}; /* LOOP END: CASE */
						 
/* Rounding up */				
forvalues j = 1(1)9{;

	foreach i in 2 3 4 8 9 10 11{;
		matrix table6[`i',`j'] = round(table6[`i',`j']/1000000,0.1)*1000;
	};
	
	matrix table6[5,`j']  = table6[2,`j'] + table6[3,`j'] +	table6[4,`j'];	
	matrix table6[12,`j'] = table6[8,`j'] + table6[9,`j'] +	table6[10,`j'] + table6[11,`j'];	
	matrix table6[14,`j'] = round(table6[14,`j'] ,0.1);
};
				
matrix colnames table6 = "MHVH_log" "MHVH_crra2" "MHVH_crra4"
						 "HVH_log"  "HVH_crra2"  "HVH_crra4"
						 "VH_log"   "VH_crra2"   "VH_crra4";
						 
matrix rownames table6 = "Cost ($1k)"
								"Lower receipt in closing ZIPs" 
								"Lower receipt in neighbor ZIPs" 
								"Higher app time + earnings decay" 
								"Total" 
						 "----------"
						 "Benefit ($1k)" 
								"Benf sav - disc underserving"
								"Admin sav - fewer applicants" 
								"Admin sav - closing FO" 
								"App cost sav - discouraged" 
								"Total" 
						 "----------"		
						 "Ratio of costs to benefits";		
}; /* LOOP END: Suppress output */
				 
/* FINAL OUTPUT: Table 6 */
matrix list table6, 
			title("Table 6: Welfare Calculation: Costs and Benefits of Field Office Closings");
