capture log close
clear all
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Create Table 7
Input: 
	cba_FOclszip (created from SSA data, located in folder ../offices/data/zip)
	cba_collapse_formerge (from SAS program AEJ_PREP_831_4TABLE67)
	cba_FOnbrzip (created from SSA data, located in folder ../offices/data/zip)
*/

/* ************************************************* */
/* **** COSTS OF CLOSINGS FOR CLOSING ZIP CODES **** */
/* ************************************************* */

/* Input file: for each potential office closing, lists all closing ZIPs */
use "`data'\cba_FOclszip.dta", clear;
rename closingzip zip;
rename closed_office office;

/* Merge in file that tells us: if a ZIP is ever a closing ZIP, how much would the closing cost for that ZIP? */
merge m:1 zip using "`data'\cba_collapse_formerge.dta", 
	keepusing(
	t7g1cost_cls* t7g1ben_cls*
	sum_* den_*
	t7_cls_disc t7_cls_keep 
	);
drop if _merge==2;
drop _merge;

gen t7_cls_count = t7_cls_disc + t7_cls_keep ;
count ;

gen cls_zipnum=1; 

/* Cost of each office closing (based on 1999) for the closing ZIPs */
collapse (sum) 	
				t7g1cost_cls* t7g1ben_cls*
				sum_* den_* cls_zipnum 
				t7_cls_count t7_cls_disc t7_cls_keep
		(mean) 	actual_close, by(office); 

gen avg_ed=sum_ed/den_ed;

egen sum_sevall=rowtotal(sum_sev*);
foreach stub in low med high vh {;
	gen avg_sev`stub'=sum_sev`stub'/sum_sevall;
};

egen sum_tocall=rowtotal(sum_diadult sum_ssiadult sum_ssikid);
foreach stub in diadult ssiadult ssikid {;
	gen avg_`stub'=sum_`stub'/sum_tocall;
};

save "`data'\cba_FOclszipcost.dta", replace;


/* ***************************************************** */
/* **** COSTS OF CLOSINGS FOR NEIGHBORING ZIP CODES **** */
/* ***************************************************** */

/* Input file: for each potential closing, list all neighboring ZIPs */
use "`data'\cba_FOnbrzip.dta", clear;
rename neighboringzip zip;
rename closed_office office;

/* Merge in file that tells us: if a ZIP is ever a neighboring ZIP, how much would the closing cost for that ZIP? */
merge m:1 zip using "`data'\cba_collapse_formerge.dta", 
	keepusing(
	t7g1cost_nbr* t7g1ben_nbr*
	sum_* den_*
	t7_nbr_disc t7_nbr_keep 
	);
drop if _merge==2;
drop _merge;

gen t7_nbr_count = t7_nbr_disc + t7_nbr_keep ;
count ;

gen nbr_zipnum=1; 

/* Cost of each office closing (based on 1999) for the closing ZIPs */
collapse (sum) 	
				t7g1cost_nbr* t7g1ben_nbr*
				sum_* den_* nbr_zipnum 
				t7_nbr_count t7_nbr_disc t7_nbr_keep
				, by(office); 
			   
save "`data'\cba_FOnbrzipcost.dta", replace;


/* ************************************************************* */
/* **** MERGE CLOSING AND NEIGHBORING COSTS FOR EACH OFFICE **** */
/* ************************************************************* */

merge 1:1 office using "`data'\cba_FOclszipcost.dta";
drop _merge;
				
foreach var of varlist t7g1* {;
	replace `var'=`var'/1000;
};

/* Consider cost and savings (per closing) from shutting down FO 
SSA testimony: $4 million over 10 years, plus cost of public funds (.2)*/
foreach prefix in t7g1 {;

	gen `prefix'cost_timedecay = `prefix'cost_cls_timedecay + `prefix'cost_nbr_timedecay;
	gen `prefix'cost_total = `prefix'cost_cls_diins + `prefix'cost_nbr_diins + `prefix'cost_timedecay ;
	
	gen `prefix'ben_adminapp = `prefix'ben_cls_adminapp + `prefix'ben_nbr_adminapp ;
	gen `prefix'ben_appsave  = `prefix'ben_cls_appsave  + `prefix'ben_nbr_appsave  ;
	gen `prefix'ben_total    = `prefix'ben_adminapp + `prefix'ben_appsave + ((4000000/10)/1000)*1.2 ;
	
	gen `prefix'netcost    = `prefix'cost_total - `prefix'ben_total ; 
};

foreach prefix in t7g1 {;
	local `prefix'_totcost_subgp `prefix'netcost `prefix'cost_* `prefix'ben_* ;
};

/* Summ all costs */
foreach prefix in t7g1 {;
	summ ``prefix'_totcost_subgp';
};

/* 118 lowest cost closings */
foreach prefix in t7g1 {;
	sort `prefix'netcost;
	gen `prefix'_optimal118_n=_n;
	gen byte `prefix'_optimal118=(`prefix'_optimal118_n<=118);
};

/* How many of lowest-cost closings were actual closings?*/
count if t7g1_optimal118==1;
count if actual_close==1;
count if t7g1_optimal118==1 & actual_close==1;

/* 20 lowest cost closings, other than those that actually closed */
foreach prefix in t7g1 {;
	sort actual_close `prefix'netcost;
	gen `prefix'_next20_n=_n if actual_close==0;
	gen byte `prefix'_next20=(`prefix'_next20_n<=20);
};

/* Merge in office characteristics */
gen year=1999;
rename office office1;
merge 1:1 office1 year using "`data'\fo_chars_year_complete.dta", keepusing(numberFO_lessthan20) ;
drop if _merge==2;
rename office1 office;
drop _merge year;

/* Table 7 actual closings: Using 1999 for application count */
foreach prefix in t7g1 {;
	summ 
		`prefix'cost_cls_diins `prefix'cost_nbr_diins `prefix'cost_timedecay `prefix'cost_total 
		`prefix'ben_adminapp `prefix'ben_appsave `prefix'ben_total 
		`prefix'netcost
		if actual_close
		;
};

/* Table 7 main: Using 1999 for application count, summ costs and characteristics for 
	all offices, actually closed 118, optimal 118, and next lowest cost 20 */
gen all=1 ;
foreach prefix in t7g1 {;
	foreach group in all actual_close `prefix'_optimal118 `prefix'_next20 { ;
		disp "***** SUMMARY STATS FOR `prefix' `group' ****** ";
		summ 
			`prefix'netcost cls_zipnum nbr_zipnum numberFO_lessthan20 
			t7_cls_count t7_nbr_count  
			avg_ed avg_diadult avg_ssiadult avg_ssikid avg_sevlow avg_sevmed avg_sevhigh avg_sevvh 
		if `group'==1;
	};
};

/* Table 7 details: where is lower cost coming from? */
foreach prefix in t7g1 {;
	foreach group in all actual_close `prefix'_optimal118 `prefix'_next20 { ;
		disp "***** SUMMARY STATS FOR `prefix' `group' ****** ";
		summ 
			`prefix'cost_cls_diins `prefix'cost_nbr_diins `prefix'cost_timedecay `prefix'cost_total 
			`prefix'ben_adminapp `prefix'ben_appsave `prefix'ben_total 
			`prefix'netcost
		if `group'==1;
	};
};
