capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Appendix Table A.11
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

local list_a_all "all_a_ctnum all_a_ctsevlow all_a_ctsevmed all_a_ctsevhigh all_a_ctsevvh all_a_ctbsmental all_a_ctbsmusc all_a_ctbsphys all_a_ctedhsdrop all_a_ctedhsgrad all_a_ctedcollgrad all_a_ctage18to34 all_a_ctage35to49 all_a_ctage50plus"; 
local list_a_all_earn "all_a_ctpearn0 all_a_ctpearn5 all_a_ctpearn15 all_a_ctpearn25" ;
local list_r_all "all_r_ctnum all_r_ctsevmed all_r_ctsevhigh all_r_ctsevvh all_r_ctbsmental all_r_ctbsmusc all_r_ctbsphys all_r_ctedhsdrop all_r_ctedhsgrad all_r_ctedcollgrad all_r_ctage18to34 all_r_ctage35to49 all_r_ctage50plus" ;
local list_r_all_earn "all_r_ctpearn0 all_r_ctpearn5 all_r_ctpearn15 all_r_ctpearn25" ;


/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

/* Pre/post dummies */
keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Recode states and years to add stateXyear fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ********************************************* */
/* **** PRE-POST REGRESSIONS (APPLICATIONS) **** */
/* ********************************************* */

foreach stub in all {;
	xi: areg `stub'_a_ctnum
			trtXpost trtXzero treat i.eqtryear  
			if sample_`stub'==1
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table11A.xls", replace;
};

foreach stub in all {;
	foreach var of varlist 
		`list_a_`stub'' 
		{;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_`stub'==1
				/* no weights */
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table11A.xls", append;
	};
};

foreach stub in all  {;
	foreach var of varlist 
		`list_a_`stub'_earn' 
		{;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_`stub'==1
				/*no weights*/
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table11A.xls", append;
	};
};

/* ******************************************* */
/* **** PRE-POST REGRESSIONS (RECIPIENTS) **** */
/* ******************************************* */

foreach stub in all {;
	xi: areg `stub'_r_ctnum
			trtXpost trtXzero treat i.eqtryear  
			if sample_`stub'==1
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table11R.xls", replace;
};

foreach stub in all {;
	foreach var of varlist 
		`list_r_`stub''
		{;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear`i' i.quarter 
				if sample_`stub'==1
				/*no weights*/
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table11R.xls", append;
	};
};

foreach stub in all {;
	foreach var of varlist 
		`list_r_`stub'_earn'
		{;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter 
				if sample_`stub'==1
				/*no weights*/
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table11R.xls", append;
	};
};
