capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Appendix Table A.12
See SAS program AEJ_PREP_831_2APPEND for first panel of Appendix Table A.12
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;


/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;


/* ****************************** */
/* **** PRE-POST REGRESSIONS **** */
/* ****************************** */

	xi: areg all_a_ctnum
		trtXpost trtXzero treat
		i.eqtryear i.stateXyear i.quarter  
		if sample_`stub'==1
		[aweight=weight_a_`stub']
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table12.xls", replace;

	foreach var of varlist 
		all_a_ctxdroplow all_a_ctxdropmed all_a_ctxdrophigh all_a_ctxdropvh all_a_ctxhslow all_a_ctxhsmed all_a_ctxhshigh all_a_ctxhsvh all_a_ctxcolllow all_a_ctxcollmed all_a_ctxcollhigh all_a_ctxcollvh all_a_ctxdropment all_a_ctxdropmusc all_a_ctxdropphys all_a_ctxhsment all_a_ctxhsmusc all_a_ctxhsphys all_a_ctxcollment all_a_ctxcollmusc all_a_ctxcollphys all_a_ctxmentlow all_a_ctxmentmed all_a_ctxmenthigh all_a_ctxmentvh all_a_ctxphyslow all_a_ctxphysmed all_a_ctxphyshigh all_a_ctxphysvh all_a_ctxmusclow all_a_ctxmuscmed all_a_ctxmuschigh all_a_ctxmuscvh {;
		xi: areg `var' 
				trtXpost trtXzero treat
				i.eqtryear i.stateXyear i.quarter  
				if sample_all==1
				[aweight=weight_a_all]
			, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table12.xls", append;
	};
