capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Appendix Table A.13
Input: 
	zip_for831merge_qtr (from AEJ_831QTR_PREP3)
	collapse_zipappall_qtr (from SAS program AEJ_PREP_831_3COLLAPSE)
	fo_chars_year (created from office locations and GIS, located in folder ../offices/data/zip)
	waittime_formerge_yr (from AEJ_PREP_WAIT)
*/

/* ************************************ */
/* **** COLLAPSE MAIN SSA DATA SET **** */
/* ************************************ */

use "`data'\zip_for831merge_qtr.dta", clear;
merge 1:1 zip year quarter using "`data'\collapse_zipappall_qtr.dta", 
	keepusing(all_a_ctnum all_a_daysproc);
	foreach var of varlist all_a_ct* {;
		replace `var'=0 if _merge==1;
	};
	drop if _merge==2;
	drop _merge;

/* Create weights */
gen temp=all_a_ctnum if year==2000;
egen weight=mean(temp), by(zip);

collapse 	(sum) all_a_ctnum 
		(mean) all_a_daysproc
		[aweight=weight]
		,
		by(office1 year);
			
save "`data'\zip_forfocharmerge_year.dta", replace;

			
/* **************************************** */
/* **** MERGE SSA DATA INTO FO DATASET **** */
/* **************************************** */
use "`data'\fo_chars_year.dta", clear;
rename office_number office1;

merge 1:1 office1 year using "`data'\zip_forfocharmerge_year.dta";
drop _merge;
merge 1:1 office1 year using "`data'\waittime_formerge_yr.dta", keepusing(waitno_avg);
drop _merge;

save "`data'\fo_chars_year_complete.dta", replace;

/* Wait time in year before */
forval yr=2005(1)2015 {;
	gen temp_`yr'=waitno_avg if year==`yr';
	egen wait_`yr'=max(temp_`yr'), by(office1);
};
gen wait_prevyr=.;
forval yr=2006(1)2015 {;
	replace wait_prevyr=wait_`=`yr'-1' if year==`yr';
};
drop temp*;

/* Processing time in year before */
forval yr=1999(1)2015 {;
	gen temp_`yr'=all_a_daysproc if year==`yr';
	egen daysproc_`yr'=max(temp_`yr'), by(office1);
};
gen proc_prevyr=.;
forval yr=2000(1)2015 {;
	replace proc_prevyr=daysproc_`=`yr'-1' if year==`yr';
};
drop temp*;

/* Applications in year before */
forval yr=1999(1)2015 {;
	gen temp_`yr'=all_a_ctnum if year==`yr';
	egen apps_`yr'=max(temp_`yr'), by(office1);
};
gen apps_prevyr=.;
forval yr=2000(1)2015 {;
	replace apps_prevyr=apps_`=`yr'-1' if year==`yr';
};
drop temp*;

/* Closing year */
egen close_year=max(year) if nowopen==1, by(office1);
tab close_year, m;

/* Rename variables */
gen density2000=Population/area;
rename Population pop2000;
foreach i in 1 5 10 20 40 80 160 {;
	rename numberFO_lessthan`i' numoffice`i';
};

summ if year==2000;


/* **************************************** */
/* **** OFFICE EVER CLOSES REGRESSIONS **** */
/* **************************************** */

reg everclosed apps_prevyr, r;
outreg2 using "`output'\table13.xls", replace;

forval year=2000(1)2005 {;
	preserve;
	keep if year==`year' & nowopen==1;

	reg everclosed pop2000 density2000 apps_prevyr proc_prevyr numoffice20, r;
	outreg2 using "`output'\table13.xls", append;
	restore;
};

forval year=2006(1)2012 {;
	preserve;
	keep if year==`year' & nowopen==1;
	
	reg everclosed pop2000 density2000 apps_prevyr proc_prevyr numoffice20 wait_prevyr, r;
	outreg2 using "`output'\table13.xls", append;
	restore;
};


/* *************************************** */
/* **** TIMING OF CLOSING REGRESSIONS **** */
/* *************************************** */

/* Keep only closed offices */
keep if everclosed==1;
summ if year==2000;

forval year=2000(1)2005 {;
	preserve;
	keep if year==`year' & nowopen==1;

	reg close_year pop2000 density2000 apps_prevyr proc_prevyr numoffice20, r;
	outreg2 using "`output'\table13.xls", append;
	restore;
};

forval year=2006(1)2012 {;
	preserve;
	keep if year==`year' & nowopen==1;
	
	reg close_year pop2000 density2000 apps_prevyr proc_prevyr numoffice20 wait_prevyr, r;
	outreg2 using "`output'\table13.xls", append;
	restore;
};
