capture log close
clear all
set maxvar 10000
set matsize 11000
set more off
pause off
# delimit;

local output "";
local log "";
local data "";

/* 
Run regressions for Appendix Table A.17
Input: 
	zip_for831_FNqtr_forreg (from AEJ_831QTR_PREP3)
*/

use "`data'\zip_for831_FNqtr_forreg.dta", clear;

local pre "12";
local post "8";
scalar define scpre=12;
scalar define scpost=8;

/* ****************************** */
/* **** PREP FOR REGRESSIONS **** */
/* ****************************** */

keep if eqtryear>=-`=scpre' & eqtryear<=`=scpost' ;
tab eqtryear, m;

gen byte pre=(eqtryear<0);
gen byte post=(eqtryear>0);
gen byte qtrzero=(eqtryear==0);

gen trtXpost=treat*post;
gen trtXzero=treat*qtrzero;

/* Create weights */
foreach stub in waitno waitap wait {;
	gen temp_`stub'=`stub'_count if eqtryear<0 & eqtryear>=-4;
	egen weight_`stub'=mean(temp_`stub'), by(cset zip);
	drop temp_*;
};

foreach stub in all diadult ssiadult ssikid {;
	gen temp_a_`stub'=`stub'_a_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_a_`stub'=mean(temp_a_`stub'), by(cset zip);
	gen temp_r_`stub'=`stub'_r_ctnum if eqtryear<0 & eqtryear>=-4;
	egen weight_r_`stub'=mean(temp_r_`stub'), by(cset zip);
	drop temp_*;
};

/* Convert to log applications variable */
foreach stub in all diadult ssiadult ssikid {;
	summ `stub'_a_ct* `stub'_r_ct*;
	foreach var of varlist `stub'_a_ct* `stub'_r_ct* {;
		replace `var' = 1 if `var'==0;
		replace `var' = log(`var');
	};
	summ `stub'_a_ct* `stub'_r_ct*;
};

/* Heterogeneity by neighbor wait time */
summ office2_wait, det;
gen gp_wait=1 if office2_wait<15;
replace gp_wait=2 if office2_wait>=15 & office2_wait<30;
replace gp_wait=3 if office2_wait>=30 & office2_wait!=.;
tab gp_wait, m;

summ office2_waitdiff, det;
gen gp_waitdiff=1 if office2_waitdiff<0;
replace gp_waitdiff=2 if office2_waitdiff>=0 & office2_waitdiff<10;
replace gp_waitdiff=3 if office2_waitdiff>=10 & office2_waitdiff!=.;
tab gp_waitdiff, m;

/* Heterogeneity by own and neighbor distance */
summ office1_dist, det;
gen gp_dist=1 if office1_dist<10;
replace gp_dist=2 if office1_dist>=10 & office1_dist<30;
replace gp_dist=3 if office1_dist>=30 & office1_dist!=.;
tab gp_dist, m;

gen gp_distbin=1 if office1_dist<5;
replace gp_distbin=2 if office1_dist>=5  & office1_dist<10;
replace gp_distbin=3 if office1_dist>=10 & office1_dist<15;
replace gp_distbin=4 if office1_dist>=15 & office1_dist<20;
replace gp_distbin=5 if office1_dist>=20 & office1_dist<25;
replace gp_distbin=6 if office1_dist>=25 & office1_dist<30;
replace gp_distbin=7 if office1_dist>=30 & office1_dist<.;

summ office2_dist, det;
gen gp_ndist=1 if office2_dist<20;
replace gp_ndist=2 if office2_dist>=20 & office2_dist<45;
replace gp_ndist=3 if office2_dist>=45 & office2_dist!=.;
tab gp_ndist, m;

summ office2_distdiff, det;
gen gp_distdiff=1 if office2_distdiff<10;
replace gp_distdiff=2 if office2_distdiff>=10 & office2_distdiff<30;
replace gp_distdiff=3 if office2_distdiff>=30 & office2_distdiff!=.;
tab gp_distdiff, m;

/* Heterogeneity by county unemployment rate */
summ urate_pre, det;
gen gp_uratepre=1 if urate_pre<4;
replace gp_uratepre=2 if urate_pre>=5 & urate_pre<7;
replace gp_uratepre=3 if urate_pre>=7 & urate_pre!=.;
tab gp_uratepre, m;

/* Heterogeneity by urban/rural */
summ density, det;
gen gp_dens=1 if density<30;
replace gp_dens=2 if density>=30 & density<300;
replace gp_dens=3 if density>=300 & density!=.;
tab gp_dens, m;

/* Heterogeneity by SSA population */
gen gp_ssaprop_all=1 if ssaprop_all<0.03;
replace gp_ssaprop_all=2 if ssaprop_all>=0.03 & ssaprop_all<0.05;
replace gp_ssaprop_all=3 if ssaprop_all>=0.05 & ssaprop_all!=.;
tab gp_ssaprop_all, m;

gen gp_ssaprop_diadult=1 if ssaprop_diadult<0.02;
replace gp_ssaprop_diadult=2 if ssaprop_diadult>=0.02 & ssaprop_diadult<0.025;
replace gp_ssaprop_diadult=3 if ssaprop_diadult>=0.025 & ssaprop_diadult!=.;
tab gp_ssaprop_diadult, m;

gen gp_ssaprop_ssiadult=1 if ssaprop_ssiadult<0.015;
replace gp_ssaprop_ssiadult=2 if ssaprop_ssiadult>=0.015 & ssaprop_ssiadult<0.025;
replace gp_ssaprop_ssiadult=3 if ssaprop_ssiadult>=0.025 & ssaprop_ssiadult!=.;
tab gp_ssaprop_ssiadult, m;

gen gp_ssaprop_ssikid=1 if ssaprop_ssikid<0.002;
replace gp_ssaprop_ssikid=2 if ssaprop_ssikid>=0.002 & ssaprop_ssikid<0.0035;
replace gp_ssaprop_ssikid=3 if ssaprop_ssikid>=0.0035 & ssaprop_ssikid!=.;
tab gp_ssaprop_ssikid, m;

summ zipapp_pc9600, det;
gen gp_apppc=1 if zipapp_pc9600<0.4;
replace gp_apppc=2 if zipapp_pc9600>=.4 & zipapp_pc9600<.7;
replace gp_apppc=3 if zipapp_pc9600>=.7;
tab gp_apppc, m;

/* Heterogeneity by broadband access */
summ fcc_provnum, det;
gen gp_fccprov=1 if fcc_provnum<10;
replace gp_fccprov=2 if fcc_provnum>=10 & fcc_provnum<20;
replace gp_fccprov=3 if fcc_provnum>=20 & fcc_provnum!=.;
tab gp_fccprov, m;

summ fcc_access, det;
gen gp_fcchh=1 if fcc_access<2.8;
replace gp_fcchh=2 if fcc_access>=2.8 & fcc_access<3.5;
replace gp_fcchh=3 if fcc_access>=3.5 & fcc_access!=.;
tab gp_fcchh, m;

/* Heterogeneity by EITC knowledge variation */
summ chetty_eitc, det;
gen gp_eitcvar=1 if chetty_eitc<0.01;
replace gp_eitcvar=2 if chetty_eitc>=.01 & chetty_eitc<.02;
replace gp_eitcvar=3 if chetty_eitc>=.02 & chetty_eitc!=.;
tab gp_eitcvar, m;

/* State X year fixed effects */
drop if year==2015 & (quarter==3 | quarter==4);
tab statecode, m;
tab year, m;
egen stateXyear=group(statecode year);
tab stateXyear, m;
gen unique=_n;
egen temp=count(unique), by(stateXyear);
tab temp, m;
summ temp;
pctile pct=temp, n(100);
local p10=pct[10];
replace stateXyear=9999 if temp<`p10' ;
tab stateXyear, m;
drop pct temp;

/* ******************************** */
/* **** HETEROGENEITY ANALYSIS **** */
/* ******************************** */

xi: areg all_r_ctnum
		trtXpost trtXzero i.eqtryear  
		if sample_all==1
	, absorb(zip) vce(cluster closing);
outreg2 using "`output'\table17.xls", replace;

foreach hetero in gp_ssaprop_all gp_apppc gp_eitcvar {;
foreach gp in a {;
foreach stub in all {;
forval i=1(1)3 {;
	xi: areg `stub'_`gp'_ctnum
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter 
			if sample_all==1 & `hetero'==`i'
			[aweight=weight_`gp'_all]
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table17.xls", append;
};
};
};
};

foreach hetero in gp_fccprov gp_fcchh {;
foreach gp in a {;
forval i=1(1)3 {;
	xi: areg all_`gp'_ctnum 
			trtXpost trtXzero treat
			i.eqtryear i.stateXyear i.quarter 
			if sample_all==1 & `hetero'==`i' & qtryear>=yq(2006,1)
			[aweight=weight_`gp'_all]
		, absorb(zip) vce(cluster closing);
	outreg2 using "`output'\table17.xls", append;
};
};
};